
(* SPAN - A Security Protocol Animator
   Copyright (C) 2006-2009 Yann Glouche, Thomas Genet, Olivier Heen, 
   	     	 	   Erwan Houssay and Ronan Saillard.

   The CAS+ Parser includes source code from the CASRUL tool
   CASRUL: Copyright (C) 2001 Florent Jacquemard, Michael Rusinowitch and
      		    	      Laurent Vigneron.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License version 2, as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

   See the GNU Library General Public License version 2 for more details
   (enclosed in the file LGPL).


   Version 1.6. Last modification 16/07/09
*)
open Types;;
open Printer;;

(* ----------------
   supp_doublons : a' list -> a' list
   ---------------- *)
let rec supp_doublons l = match l with
  [] -> []
| a::reste -> if List.mem a reste then supp_doublons reste else a::(supp_doublons reste)
;;

(* ----------------
   supp_doublons_k : (a' * b' list) list -> (a' * b' list) list
   ---------------- *)
let rec supp_doublons_k l = match l with
  [] -> []
| (i,a)::reste -> (i,(supp_doublons a))::(supp_doublons_k reste)
;;

(* ----------------
   supp_doublons_s : ((string * string) list) list -> ((string * string) list) list             A VERIFIER !!!
   ---------------- *)
let rec supp_doublons_s l =
  let rec sd l = ( match l with
	  [] -> []
	| (s1,s2)::reste -> if List.exists (fun e -> let (_,s)=e in s2=s) reste then (sd reste) else (s1,s2)::(sd reste)
 ) in match l with
  [] -> []
| a::reste -> (sd a)::(supp_doublons_s reste)
;;

(* ----------------
   supp_doublons_g : (a',goal_type) list -> (a',goal_type) list
   ---------------- *)
let rec supp_doublons_g goals = match goals with
  [] -> []
| (i,Secrecy(s,l))::reste -> (i,Secrecy(s,supp_doublons l))::(supp_doublons_g reste)
| (i,Authentication(a,b,c))::reste -> (i,Authentication(a,b,c))::(supp_doublons_g reste)
| (i,Weak_authentication(a,b,c))::reste -> (i,Weak_authentication(a,b,c))::(supp_doublons_g reste)
;;

(* ----------------
   check_double_dec : (string * b') list -> unit
   ---------------- *)
let rec check_double_dec idents = let err = ref false in
	let rec doublon c l = match l with 
		  [] -> false
		| (s,_)::reste -> s=c || doublon c reste
	in match idents with 
	  [] -> ()
	| (s,_)::reste -> (
		if s<>(String.capitalize s) then (prerr_string ("ERROR : Identifier "^s^" must begin with a capital letter.\n");err:=true);
		if doublon s reste then (prerr_string ("ERROR : Identifier "^s^" is declared two times.\n");err:=true);
		check_double_dec reste );
	if !err then exit(0)
;;

(* ----------------
   check_msgs : (string * type_var) list -> (int * string * string * msg) list -> unit
   ---------------- *)
let rec check_msgs idents msgs = let err = ref false in	
	let rec check_m msg = match msg with
  		  Id s -> if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true)
  		| Int _ -> ()
  		| Func (s,m) ->
			if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true);
			if (getType idents s)<>Function then (prerr_string ("ERROR : Identifier "^s^" has type "^(print_type_var (getType idents s))^" but is used with type Function.\n");err:=true);
			check_m m
  		| Crypt (m1,m2) -> check_m m1;check_m m2
  		| Exp (m1,m2) -> check_m m1;check_m m2
  		| Xor (m1,m2) -> check_m m1;check_m m2
  		| Pair (m1,m2) -> check_m m1;check_m m2
  		| Inv s -> 
			if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true);
			if (getType idents s)<>PcKey then (prerr_string ("ERROR : Identifier "^s^" has type "^(print_type_var (getType idents s))^" but is used with type Public key.\n");err:=true);
  		| TableElt (s1,s2) ->
			if (getType idents s1)=Error then (prerr_string ("ERROR : Identifier "^s1^" must be declared before use.\n");err:=true);
			if (getType idents s2)=Error then (prerr_string ("ERROR : Identifier "^s2^" must be declared before use.\n");err:=true);
			if (getType idents s1)<>Table then (prerr_string ("ERROR : Identifier "^s1^" has type "^(print_type_var (getType idents s1))^" but is used with type Table.\n");err:=true);
  		| TableEltInv (s1,s2) ->
			if (getType idents s1)=Error then (prerr_string ("ERROR : Identifier "^s1^" must be declared before use.\n");err:=true);
			if (getType idents s2)=Error then (prerr_string ("ERROR : Identifier "^s2^" must be declared before use.\n");err:=true);
			if (getType idents s1)<>Table then (prerr_string ("ERROR : Identifier "^s1^" has type "^(print_type_var (getType idents s1))^" but is used with type Table.\n");err:=true);
	in match msgs with
	  [] -> ()
	| (_,i,exp,dest,m)::reste -> (
		if i<0 then (prerr_string ("ERROR : Identifiers of messages must be positive integers.\n");err:=true);
		if (getType idents exp)=Error then (prerr_string ("ERROR : Identifier "^exp^" must be declared before use.\n");err:=true);
		if (getType idents dest)=Error then (prerr_string ("ERROR : Identifier "^dest^" must be declared before use.\n");err:=true);
		if (getType idents exp)<>User then (prerr_string ("ERROR : Identifier "^exp^" has type "^(print_type_var (getType idents exp))^" but is used with type User.\n");err:=true);
		if (getType idents dest)<>User then (prerr_string ("ERROR : Identifier "^dest^" has type "^(print_type_var (getType idents dest))^" but is used with type User.\n");err:=true);
		check_m m;
		check_msgs idents reste);
	if !err then exit(0)
;;

(* ----------------
   check_knowledge : (string * type_var) list -> (string * string list) list -> unit
   ---------------- *)
let rec check_knowledge idents knowledge = let err = ref false in
	let rec check_decl l = match l with
	  [] -> ()
	| s::reste ->
		if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true);
		check_decl reste
	in match knowledge with
	  [] -> ();
	| (s,l)::reste -> (
		if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true);
		if (getType idents s)<>User then (prerr_string ("ERROR : Identifier "^s^" has type "^(print_type_var (getType idents s))^" but is used with type User.\n");err:=true);
		check_decl l;
		check_knowledge idents reste
	);
	if !err then exit(0)
;;

(* ----------------
   check_sessions : (string * type_var) list -> (string * string) list list -> unit
   ---------------- *)
let rec check_sessions idents sessions = let err = ref false in 
	let rec check_sess sess = (match sess with
	  [] -> ()
	| (id,cons)::reste -> (
		if (getType idents id)=Error then (prerr_string ("ERROR : Identifier "^id^" must be declared before use.\n");err:=true);
		if cons<>(String.uncapitalize cons) then (prerr_string ("ERROR : Identifier "^cons^" must begin with a lowercase letter.\n");err:=true);
		check_sess reste
	)) in
	List.iter check_sess sessions;
	if !err then exit(0)
;;


(* ----------------
   inv_of_publickey : string -> string -> bool
   ---------------- *)

(* checks if c="inv("^s^")" *)
let inv_of_publickey c s=
  ((String.length c)>5)&&((String.sub c 0 4)="inv(")&&((String.sub c 4 ((String.length c)-5)) = s)
    

(* ----------------
   check_intruder : ('a * string) list list -> string list -> unit
   ---------------- *)

let rec check_intruder sessions intruder = let err = ref false in
	let rec check_c c sessions = match sessions with
	  [] -> false;
	| l::reste -> 
		let rec check_c_2 sess = (match sess with
		  [] -> false
		| (_,s)::reste2 -> s=c or inv_of_publickey c s or check_c_2 reste2
		) in (check_c_2 l) || (check_c c reste)
	in match intruder with
	  [] -> ()
	| c::reste -> (
		if not (check_c c sessions) then (prerr_string ("ERROR : Intruder knowledge "^c^" must be declared in session_instances.\n");err:=true);
		check_intruder sessions reste);
	if !err then exit(0)
;;

(* ----------------
   check_goals : (string * type_var) list -> ('a * goal_type) list -> unit
   ---------------- *)
let rec check_goals idents goals = 
 let err = ref false in
 (match goals with
   [] -> ()
 | (_,g)::reste -> 
	(match g with
	  Secrecy (s,l) ->
		if (getType idents s)=Error then (prerr_string ("ERROR : Identifier "^s^" must be declared before use.\n");err:=true);
		List.iter (fun e -> 
		  if (getType idents e)=Error then (prerr_string ("ERROR : Identifier "^e^" must be declared before use.\n");err:=true);
		  if (getType idents e)<>User then (prerr_string ("ERROR : Identifier "^e^" has type "^(print_type_var (getType idents e))^" but is used with type User.\n");err:=true);) l
	| Authentication (a,b,n) -> 
	  if (getType idents a)=Error then (prerr_string ("ERROR : Identifier "^a^" must be declared before use.\n");err:=true);
	  if (getType idents a)<>User then (prerr_string ("ERROR : Identifier "^a^" has type "^(print_type_var (getType idents a))^" but is used with type User.\n");err:=true);
	  if (getType idents b)=Error then (prerr_string ("ERROR : Identifier "^b^" must be declared before use.\n");err:=true);
	  if (getType idents b)<>User then (prerr_string ("ERROR : Identifier "^b^" has type "^(print_type_var (getType idents b))^" but is used with type User.\n");err:=true);
	  if (getType idents n)=Error then (prerr_string ("ERROR : Identifier "^n^" must be declared before use.\n");err:=true);
	  if (getType idents n)<>Number then (prerr_string ("ERROR : Identifier "^n^" has type "^(print_type_var (getType idents n))^" but is used with type Number.\n");err:=true)
	| Weak_authentication (a,b,n) ->
	  if (getType idents a)=Error then (prerr_string ("ERROR : Identifier "^a^" must be declared before use.\n");err:=true);
	  if (getType idents a)<>User then (prerr_string ("ERROR : Identifier "^a^" has type "^(print_type_var (getType idents a))^" but is used with type User.\n");err:=true);
	  if (getType idents b)=Error then (prerr_string ("ERROR : Identifier "^b^" must be declared before use.\n");err:=true);
	  if (getType idents b)<>User then (prerr_string ("ERROR : Identifier "^b^" has type "^(print_type_var (getType idents b))^" but is used with type User.\n");err:=true);
	  if (getType idents n)=Error then (prerr_string ("ERROR : Identifier "^n^" must be declared before use.\n");err:=true);
	  if (getType idents n)<>Number then (prerr_string ("ERROR : Identifier "^n^" has type "^(print_type_var (getType idents n))^" but is used with type Number.\n");err:=true)
	);check_goals idents reste
);if !err then exit(0)
;;

(* ----------------
   check_protocol : string -> (string * type_var) list -> (int * string * string * msg) list * (string * string list) list -> (string * string) list list -> string list * (int * goal_type) list -> struct_protocol
   ---------------- *)
let check_protocol name idents msg_and_know sessions intruder_and_goal =
	(*
		Vérifications :
		 Pas de double déclaration dans idents
		 Tout ident commence par une majuscule
		 Dans un message tout ident a préalablement été déclaré
		 num>0
		 Les types function, table et pckey sont correctement utilisés
		 Les expediteurs et destinataire d'un message sont de type user
		 Dans une liste de connaissance tout ident a préalablement été declaré
		 Une liste de connaissance appartient a un user
		 Suppression des doublons dans les listes de connaissances
		 Une constante de session commence par une minuscule
		 Dans une session tout ident a préalablement été déclaré
		 Suppression des doublons dans les sessions
		 Les connaissances de l'intru sont parmi les constantes de sessions
		 Suppression des doublons dans les connaissances de l'intru
		 Authentication User,User,Number et idents déclarés
		 secrecy_of _,[ User* ] et suppression doublons et idents déclarés
		-> TODO : Si (weak) authentication A,B,N Alors N doit etre echangé entre A et B sinon le hlspl généré est incorrecte
	*)
	check_double_dec idents;
	check_msgs idents (fst msg_and_know);
	check_knowledge idents (snd msg_and_know);
	check_sessions idents sessions;
	check_intruder sessions (fst intruder_and_goal);
	check_goals idents (snd intruder_and_goal);

	{name=name;
	idents=idents;
	messages=(fst msg_and_know);
	knowledge= supp_doublons_k (snd msg_and_know);
	sessions=supp_doublons_s sessions;
	intruder=supp_doublons (fst intruder_and_goal);
	goals=supp_doublons_g (snd intruder_and_goal);}
;;
