(* File lexer.mll *)
{
open Types;;
open Parser_proto;;        (* The type token is defined in parser_proto.mli *)

let keyword_table = Hashtbl.create 53;;
List.iter (fun (kwd, tok) -> Hashtbl.add keyword_table kwd tok)
          [ "AUTHENTICATES", AUTH;
            "FUNCTION", FUNCTION;
            "GOAL", GOAL;
            "I", INTRUDER_ID;
            "IDENTIFIERS", IDENTIFIERS;
            "INTRUDER_KNOWLEDGE", INTRUDER_KNLGE;
            "KNOWLEDGE", KNOWLEDGE;
            "MESSAGES", MESSAGES;
            "NUMBER", NUMBER;
            "PROTOCOL", PROTOCOL;
            "PUBLIC_KEY", PKEY;
            "SECRECY_OF", SECRECY;
            "SESSION_INSTANCES", S_INST;
            "SYMMETRIC_KEY", SKEY;
            "TABLE", TABLE;
            "USER", USER;
	    "ON", ON;
	    "WEAK_AUTHENTICATES", WAUTH ];;
}

rule token = parse
    [' ' '\t']     { token lexbuf }
  | '\n'           { incr cpt_line;
                     token lexbuf }
  | '%' [^ '\n']*  { token lexbuf }
  | ['0'-'9']+     { INT(int_of_string(Lexing.lexeme lexbuf)) }
  | '\''           { REV_KEY }
  | '.'            { DOT }
  | ':'            { COLON }
  | ';'            { SEMICOLON }
  | ','            { COMMA }
  | '('            { LPAR }
  | ')'            { RPAR }
  | '{'            { LBRA }
  | '}'            { RBRA }
  | '['            { LSQB }
  | ']'            { RSQB }
  | '+'            { PLUS }
  | '-'            { MINUS }
  | '*'            { TIMES }
  | '/'            { DIV }
  | '^'            { EXP }
  | '#'            { XOR }
  | "->"           { ARROW }
  | "~>"           { ARROW_NW }
  | "=>"           { ARROW_P }
  | ['a'-'z' 'A'-'Z']['a'-'z' 'A'-'Z' '_' '0'-'9']*    {
                     let id = Lexing.lexeme lexbuf in
                        try (Hashtbl.find keyword_table (String.uppercase id))
                        with Not_found -> 
				if String.contains id '_' then (
					print_string "  ERROR line ";
                			print_int !cpt_line;
                			print_string ": Forbidden character _ in ";
                			print_string (Lexing.lexeme lexbuf);
                			print_endline " ";
                			exit 0)
				else IDENT(id) }
  | eof            { EOF }
  | _              { print_string "  ERROR line ";
                     print_int !cpt_line;
                     print_string ": ";
                     print_string (Lexing.lexeme lexbuf);
                     print_endline " unknown symbol";
                     exit 0 }
