
(* SPAN - A Security Protocol Animator
   Copyright (C) 2006-2009 Yann Glouche, Thomas Genet, Olivier Heen, 
   	     	 	   Erwan Houssay and Ronan Saillard.

   The CAS+ Parser includes source code from the CASRUL tool
   CASRUL: Copyright (C) 2001 Florent Jacquemard, Michael Rusinowitch and
      		    	      Laurent Vigneron.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License version 2, as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

   See the GNU Library General Public License version 2 for more details
   (enclosed in the file LGPL).


   Version 1.6. Last modification 16/07/09
*)
open Printer;;
open Compiler;;
open Types;;


(* ----------------
   call_parser : in_channel -> int
   ---------------- *)
let call_parser channel =
  try 
	(let lexbuf = Lexing.from_channel channel in
          Parser_proto.protocol Lexer_proto.token lexbuf
	)
   with Parsing.Parse_error ->
     prerr_string "  Syntax error(";
     prerr_int !no_err;
     prerr_string ") line ";
     prerr_int !cpt_line;
     (match !no_err
     with 
	 0 -> prerr_endline ": missing PROTOCOL keyword"
       | 1 -> prerr_endline ": missing protocol name after PROTOCOL"
       | 2 -> prerr_endline ": missing semi-colon after protocol name"
       | 3 -> prerr_endline ": missing IDENTIFIERS keyword"
       | 4 -> prerr_endline ": missing KNOWLEDGE or MESSAGES keyword"
       | 5 -> prerr_endline ": missing MESSAGES keyword"
       | 6 -> prerr_endline ": missing colon in declaration"
       | 7 -> prerr_endline ": missing semi-colon at the end of a declaration of variables"
       | 8 -> prerr_endline ": missing KNOWLEDGE keyword"
       | 9 -> prerr_endline ": missing comma in a list of identifiers"
       | 10 -> prerr_endline ": missing/wrong type in variable declarations"
       | 11 -> prerr_endline ": missing comma or colon in knowledge declaration"
       | 12 -> prerr_endline ": missing comma or semi-colon in a list of knowledges"
       | 13 -> prerr_endline ": missing identifier name in list"
       | 14 -> prerr_endline ": missing identifier name in list or MESSAGES keyword"
       | 15 -> prerr_endline ": missing identifier name in list or KNOWLEDGE keyword"
       | 16 -> prerr_endline ": missing index of message"
       | 17 -> prerr_endline ": missing dot after index of message"
       | 18 -> prerr_endline ": missing sender name in message"
       | 19 -> prerr_endline ": missing arrow after sender name"
       | 20 -> prerr_endline ": missing receiver name in message"
       | 21 -> prerr_endline ": missing colon after receiver name"
       | 22 -> prerr_endline ": missing SESSION_INSTANCES keyword"
       | 23 -> prerr_endline ": missing squared bracket in session instance"
       | 25 -> prerr_endline ": missing INTRUDER_KNOWLEDGE or GOAL keyword"
       | 26 -> prerr_endline ": bad definition of GOAL strategy"
       | _ -> prerr_endline ": unknown");
	exit(0)
;;

(* ----------------
   main : unit -> unit
   ---------------- *)
let main () =
let outputFile = ref "" and debug = ref false and inputFile = ref "" and optS = ref false and optStdOut = ref false in
	(Arg.parse 
	 [("-f",Arg.String (fun s -> (outputFile := s))," (output file)");
	  ("--debug",Arg.Set(debug),"     (print debug informations)");
	  ("--stdout",Arg.Set(optStdOut),"	    (print the result in the standart output)");
	  ("--secret",Arg.Set(optS),"     (add secret decoration everywhere)");
	 ]
	 (fun s -> (inputFile := s))
	 "Usage: alicebob2hlpsl [options] input_file\n Options:");
	
    (let channel =
	(
      	try (open_in !inputFile)
      	with Sys_error(f) -> (
	  print_endline ("Error :"^f);
	  exit(0)
	  )
	) in let parse = call_parser channel in (
		if !debug then print_struct_protocol parse;
		if !outputFile = "" then outputFile := parse.name^".hlpsl";
		let out = if !optStdOut then stdout else open_out !outputFile 
		in print_struct_hlspl (protocol2Hlspl parse optS) out
	)
     )
;;

main();;  
