%{
open Types ;;
open Checker ;;

let rec decl l t = match l with
	  [] -> []
	| a::reste -> [(a,t)]@(decl reste t)
;;
let rec decl_knowledge l k = match l with
	  [] -> []
	| a::reste -> [(a,k)]@(decl_knowledge reste k)
;;
%}

%token <int> INT
%token <string> IDENT
%token PROTOCOL IDENTIFIERS KNOWLEDGE MESSAGES
%token S_INST INTRUDER_ID INTRUDER_KNLGE GOAL
%token PKEY SKEY TABLE USER FUNCTION NUMBER
%token SECRECY AUTH WAUTH ON
%token REV_KEY DOT COLON SEMICOLON COMMA ARROW ARROW_P ARROW_NW
%token LPAR RPAR LBRA RBRA LSQB RSQB
%token PLUS MINUS TIMES DIV XOR EXP
%token EOF
%left PLUS MINUS
%left TIMES DIV
%left XOR
%left EXP
%start protocol         /* the entry point */
%type <Types.struct_protocol> protocol
%%
protocol:
    PROTOCOL err1 IDENT err2 SEMICOLON
    err3 IDENTIFIERS err9
    decl_variables
    err4 knowlge_or_msgs
    sessions
    maybe_goal_or_intruder
    EOF
               { check_protocol $3 $9 $11 $12 $13 }
;

knowlge_or_msgs:
    KNOWLEDGE err13
    decl_knowledge
    err5 MESSAGES err16
    message_seq err22
               { ($7,$3) }
  | MESSAGES err16
    message_seq 
    err8 KNOWLEDGE err13
    decl_knowledge err22
               { ($3,$7) }
;

maybe_goal_or_intruder:
               {([],[])}
  | goal_or_intruder
               { $1 }
;

goal_or_intruder:
   intruder_knlge
               { ($1,[]) }
  | goal_list
		{ ([],$1) }
  | goal_list intruder_knlge
               { ($2,$1) }
  | intruder_knlge goal_list
               { ($1,$2) }
;

decl_variables:
    variable_dec
               { $1 }
  | decl_variables variable_dec
               {  $1@$2 }
;

variable_dec:
   ident_list err6 COLON err10 id_type err7 SEMICOLON err15
               { decl $1 $5 }
;

ident_list:
    IDENT err11
               { [$1] }
  | ident_list COMMA err13 IDENT err11
               { $1@[$4] }
;

id_type:
    USER       { User }
  | SKEY       { SyKey }
  | NUMBER     { Number }
  | TABLE      { Table }
  | FUNCTION   { Function }
  | PKEY       { PcKey }
;

decl_knowledge:
    knowledge_dec
               { $1 }
  | decl_knowledge knowledge_dec
               { $1@$2 }
;

knlge_ident:
    IDENT      { $1 }
;

knlge_ident_list:
    knlge_ident
               { [$1] }
  | knlge_ident_list COMMA knlge_ident
               { $1@[$3] }
;

knowledge_dec:
    ident_list COLON err12 knlge_ident_list SEMICOLON err14
               { decl_knowledge $1 $4 }
;

message_seq:
    message    { [$1] }
  | message_seq message
               { $1@[$2] }
;

message:
    INT err17 DOT err18 IDENT err19 ARROW err20 IDENT err21 COLON err99 msg_list
               { (Dolev_Yao,$1,$5,$9,$13) }
  | INT err17 DOT err18 IDENT err19 ARROW_NW err20 IDENT err21 COLON err99 msg_list
               { (Non_writable,$1,$5,$9,$13) }
  | INT err17 DOT err18 IDENT err19 ARROW_P err20 IDENT err21 COLON err99 msg_list
               { (Protected,$1,$5,$9,$13) }
;

msg_list:
    msg        { $1 }
  | msg_list COMMA msg
               { Pair($1,$3) }
;

msg:
    IDENT      { Id($1) }
  | INT        { Int($1) }
  | IDENT LPAR msg_list RPAR
               { Func($1,$3) }
  | IDENT REV_KEY
               { Inv($1) }
  | IDENT LSQB IDENT RSQB
               { TableElt($1,$3) }
  | IDENT LSQB IDENT RSQB REV_KEY
               { TableEltInv($1,$3) }
  | encryption
               { $1 }
  | msg XOR msg
               { Xor($1,$3) }
  | msg EXP msg
               { Exp($1,$3) }
  | LPAR msg RPAR
               { $2 }
;

encryption:
    LBRA msg_list RBRA encryption_key
               { Crypt($2,$4) }

  | LBRA msg_list RBRA LPAR msg RPAR 
               { Crypt($2,$5) (* ############# Chiffrement par n'importe quoi ?*) }
;

encryption_key:
    IDENT
               { Id($1) }
  | IDENT LSQB IDENT RSQB
               { TableElt($1,$3) }
  | IDENT REV_KEY
               { Inv($1) }
  | IDENT LSQB IDENT RSQB REV_KEY
               { TableEltInv($1,$3) }
;

sessions:
               { [] }
  | S_INST err23
               { [] }
  | S_INST err23 SEMICOLON err25
               { [] }
  | S_INST err23 s_instance_seq SEMICOLON err25
               { $3 }
;

s_instance_seq:
    s_instance { [$1] }
  | s_instance_seq s_instance
               { $1@[$2] }
;

s_instance:
    LSQB inst_list RSQB
               { $2 }
;

inst_list:
    inst       { [$1] }
  | inst_list COMMA inst
               { $1@[$3] }
  | inst_list SEMICOLON inst
               { $1@[$3] }
;

inst:
    IDENT COLON IDENT
               { ($1,$3) }
  | IDENT COLON INTRUDER_ID
               { ($1,"i") }
;

intruder_knlge:
    INTRUDER_KNLGE err12
               { [] }
  | INTRUDER_KNLGE err12 SEMICOLON err14
               { [] }
  | INTRUDER_KNLGE err12 real_knlge_ident_list SEMICOLON err14
               { $3 }
;

real_knlge_ident_list:
    real_knlge_ident
               { $1 }
  | real_knlge_ident_list COMMA real_knlge_ident
               { $1@$3 }
;

real_knlge_ident:
    IDENT      { [$1] }
  | IDENT REV_KEY { ["inv("^$1^")"] }   /* for private keys */
  | INTRUDER_ID
               { ["i"] }
;

goal_list:
    GOAL err26
               { [] }
  | GOAL err26 SEMICOLON
               { [] }
  | GOAL err26 seq_goal SEMICOLON
               { $3 }
;
seq_goal:
    goal 
	{ [(1,$1)] }
  | seq_goal SEMICOLON goal
	{ $1@[((List.length $1)+1,$3)] }
;
goal:
   SECRECY IDENT LSQB RSQB
          { Secrecy($2,[]) }
  | SECRECY IDENT LSQB ident_list RSQB
          { Secrecy($2,$4) }
  | IDENT AUTH IDENT ON IDENT
          { Authentication($1,$3,$5) }
  | IDENT WAUTH IDENT ON IDENT
	{ Weak_authentication($1,$3,$5) }

err1:
               { no_err := 1 }
;
err2:
               { no_err := 2 }
;
err3:
               { no_err := 3 }
;
err4:
               { no_err := 4 }
;
err5:
               { no_err := 5 }
;
err6:
               { no_err := 6 }
;
err7:
               { no_err := 7 }
;
err8:
               { no_err := 8 }
;
err9:
               { no_err := 9 }
;
err10:
               { no_err := 10 }
;
err11:
               { no_err := 11 }
;
err12:
               { no_err := 12 }
;
err13:
               { no_err := 13 }
;
err14:
               { no_err := 14 }
;
err15:
               { no_err := 15 }
;
err16:
               { no_err := 16 }
;
err17:
               { no_err := 17 }
;
err18:
               { no_err := 18 }
;
err19:
               { no_err := 19 }
;
err20:
               { no_err := 20 }
;
err21:
               { no_err := 21 }
;
err22:
               { no_err := 22 }
;
err23:
               { no_err := 23 }
;
err25:
               { no_err := 25 }
;
err26:
               { no_err := 26 }
;
err99:
               { no_err := 99 }
;
