
(* SPAN - A Security Protocol Animator
   Copyright (C) 2006-2009 Yann Glouche, Thomas Genet, Olivier Heen, 
   	     	 	   Erwan Houssay and Ronan Saillard.

   The CAS+ Parser includes source code from the CASRUL tool
   CASRUL: Copyright (C) 2001 Florent Jacquemard, Michael Rusinowitch and
      		    	      Laurent Vigneron.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License version 2, as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

   See the GNU Library General Public License version 2 for more details
   (enclosed in the file LGPL).


   Version 1.6. Last modification 16/07/09
*)
type type_var =
    User                 (* user id *)
  | SyKey                (* symmetric key *)
  | PcKey	         (* public key *)
  | Table                (* table name *)
  | Number               (* number (can be a nonce) *)
  | Function             (* function (never decoded) *)
  | Error
;;

type msg =
    Id of string
  | Int of int
  | Func of string * msg
  | Crypt of msg * msg
  | Exp of msg * msg
  | Xor of msg * msg
  | Pair of msg * msg
  | Inv of string
  | TableElt of string*string
  | TableEltInv of string*string
;; 

type channel_type =
   Dolev_Yao
 | Non_writable
 | Protected
;;

type goal_type =
    Secrecy of string*(string list)
  | Authentication of string * string * string
  | Weak_authentication of string * string * string
;;

type struct_protocol = {
	name:string;
	idents:(string*type_var)list;
	messages:(channel_type*int*string*string*msg) list;
	knowledge:(string*(string list)) list;
	sessions:((string*string)list)list;
	intruder:string list;
	goals:(int*goal_type) list;
};;

type role_agent = {
	name_ag:string;
	params_ag:string list;
	nonce_set_ag:string list*int;
	key_set_ag:string list*int;
	var_ag:string list;
	transitions:(int*string list*string list) list;
};;

type role_session = {
	params_s:string list;
	nonce_set_s:string list;
	key_set_s:string list;
	comp_s:string list;
	names_s:(string*string)list
};;

type role_env = {
	cons_env:string list;
	comp_env:string list;
	intruder_env:string list;
};;

type struct_hlpsl = {
	idents_func:string->type_var;
	agents:role_agent list;
	sessions_h:role_session list;
	environment:role_env;
	goals_h:string list;
};;

exception Call of string;;

let no_err = ref 0 ;;
let cpt_line = ref 1 ;;

(* ----------------
   getType : (string*type_var) list -> string -> type_var
   ---------------- *)
let rec getType idents c = match idents with
	  [] -> Error
	| (s,t)::reste -> if s=c then t else getType reste c
;;
