
(* SPAN - A Security Protocol Animator
   Copyright (C) 2006-2009 Yann Glouche, Thomas Genet, Olivier Heen, 
   	     	 	   Erwan Houssay and Ronan Saillard.

   The CAS+ Parser includes source code from the CASRUL tool
   CASRUL: Copyright (C) 2001 Florent Jacquemard, Michael Rusinowitch and
      		    	      Laurent Vigneron.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License version 2, as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

   See the GNU Library General Public License version 2 for more details
   (enclosed in the file LGPL).


   Version 1.6. Last modification 16/07/09
*)
(**
intruder.ml
@author Yann GLOUCHE
@version 1.0
@since 12/12/2005
*)
open Utils_simulator;;
open Transcript;;
open Variables;;
open Message_stack;;
open Unifytest;;
open Automate;;
open Tk;;

let compose_intruder_list_width=20;;
let compose_intruder_choices_list_width=30;;
let compose_intruder_entry_width= 10;;

(** 
  intruder mode
 *)
let intruder_mode = (ref false : bool Pervasives.ref);;

(** contains all the initial knowledge of the intruder *)
 let intruder_knowledge = (ref [] : string list Pervasives.ref);;

(** update the knowledge intruder, deduce some knwoledge with his initial knowldge
@return unit
*)
  let update_intruder_knowledge (() : unit) : unit =
	let rec find_match e l =
		match l with [] -> false
			|(x::ls) -> 	if (match_message "(Intruder_, 0)" ""  x "(Intruder_, 0)" "" e)
					then true
					else find_match e ls
	in
  	let deduce_knowledge initial_knowledge =
		let build_knowledge e y = (* e is an element of the initial knowledge *)
			let decomp_y = decompose y in
			let know_public_key_of_private_key e = 
				let decomp = decompose e in
				if(decomp=[]) then false
				else ((car decomp)="inv" && (find_match (cadr decomp) initial_knowledge))
			in
			let know_private_key_of_public_key e = 
			  ("public_key"=(get_type e)) && (find_match ("inv("^e^")") initial_knowledge) 
			in
			  if(decomp_y<>[])then(
			    (*				if((car decomp_y)="scrypt" && (cadr decomp_y)=e) then [(caddr decomp_y)] *)
			    if((car decomp_y)="scrypt" && 
					      (* Check that the cypher key unifies with e *)
					      (match_message "(Intruder_, 0)" "" (cadr decomp_y) "(Intruder_, 0)"  "" e ))
			    then [(caddr decomp_y)]
			    else if((car decomp_y)="xor" && 
						   (* Check that the xor right member unifies with e *)
						   (match_message "" "" (cadr decomp_y) ""  "" e ))
			    then [(caddr decomp_y)]
			    else if((car decomp_y)="xor" && 
						   (* Check that the xor left member unifies with e *)
						   (match_message "" "" (caddr decomp_y) ""  "" e ))
			    then [(cadr decomp_y)]
			    else if((car decomp_y)="crypt" && ((cadr decomp_y)=e) && ("public_key"=(get_type e)) && (know_private_key_of_public_key e)) 
			    then [(caddr decomp_y)]
			    else if((car decomp_y)="crypt" && ((cadr decomp_y)=e) && (not ("public_key"=(get_type e))) && (know_public_key_of_private_key e)) 
			    then [(caddr decomp_y)]
			    else if((car decomp_y)="pair") then (cdr decomp_y)
			    else []
			  )
			  else []
		in
		let rec aux2 elt l res =
		  match l with [] -> res
				|x::ls -> 	let k1 = List.map (fun e -> if(List.mem e initial_knowledge) then "" else e) (build_knowledge x elt) in
						let k2 = List.map (fun e -> if(List.mem e initial_knowledge) then "" else e) (build_knowledge elt x) in
						aux2 elt ls (k1@k2@res)
		in
		let rec aux l res =
			match l with [] -> remove_double (remove "" (List.flatten res))
				|x::ls -> aux ls ((aux2 x ls [])::res)
		in
		aux initial_knowledge []
	in
	let replay = 	let set_ref = (get_value_of_var "(Intruder_, 0)" "Set_knowledge") in
			if(is_a_set set_ref) then (
				let decomp = decompose(get_value_of_var "x" set_ref) in
				if(decomp=[]) 
				then []
				else (
					let knowledge_to_add = 
						let rec aux k =
							let tmp = deduce_knowledge k in
							if(tmp<>[]) then aux (tmp@k) 
							else k
						in aux (cdr decomp)
					in
					List.iter (fun k -> add_in_set "(Intruder_, 0)" k "(Intruder_, 0)" "Set_knowledge") knowledge_to_add;
					knowledge_to_add
				)
			)
			else []

	in
	let rec add_transition l k new_state new_actions = 
		match l with [] -> (("Intruder_,0,Set_knowledge,Listen_i",ref false)::new_state,(("Intruder_,0,Set_knowledge,Listen_i","Listen_i"), (([],[]), ([],["cons(Listen_i,Set_knowledge)"])), ("Intruder_,0,Set_knowledge,Listen_i",""))::new_actions)
			|(x::ls) ->	 let action_tmp = ( ("Intruder_,"^(string_of_int k)^",Set_knowledge,Listen_i",""), (([],[]), ([],[])), ("Intruder_,"^(string_of_int (- k))^",Set_knowledge,Listen_i", x) ) in
					let state_tmp = ("Intruder_,"^(string_of_int (- k))^",Set_knowledge,Listen_i", ref true) in
					if(List.mem action_tmp  new_actions)
					then add_transition ls k new_state new_actions
					else add_transition ls (k+1) (state_tmp::new_state) (action_tmp::new_actions)
	in
	automate:=(
	List.map
	(fun (name,id,state,actionsL) ->
		if(name="Intruder_" && id=0) 
		then (
			let (new_states,new_actions) = add_transition replay 1 [] [] in
			state:=new_states;
			(name,id,state,new_actions)
		)
		else (name,id,state,actionsL)
	)
	!automate
	)
;;

 let index_col = (ref 0 : int Pervasives.ref);;
 let getcol (() : unit) : color =
 	let l_color = [blue_light ; clicol ; red ; orange ; `Yellow ; violet_light ; `Green ; blue ] in
	index_col := (((!index_col)+1) mod 8);
	List.nth l_color (!index_col);
 ;;

 let l_entry = (ref [] : (string * string ref * (Widget.entry Widget.widget * string Pervasives.ref * Widget.listbox Widget.widget) list Pervasives.ref * string list) list Pervasives.ref);;

 
 let del_entry (message : string) (entrie : Widget.entry Widget.widget) : unit =
 	let rec aux2 l res =
		match l with [] -> List.rev res
			|(entry,record,lst)::ls -> 	if(entrie=entry)
						then aux2 ls res
						else aux2 ls ((entry,record,lst)::res);
	in
 	let rec aux l =
		match l with [] -> ()
			|(lab,value,entries,_)::ls -> 	if(lab=message)
							then (entries:= (aux2 (!entries) []) ; aux ls)
							else aux ls;
	in
	aux (!l_entry)
 ;;
 
 let update_entry (intruder_name : string) (intruder_state : string) (agent_name : string) (lab : string) (l_rec : string) : unit =
 	
	let simul_affectation unif str =
		let res = ref str in
		List.iter (fun (_,value,_,variable) -> res:=(replace variable value (!res))) unif;
		!res
	in
	let aux lab l_rec l = 
		let(exist_match,sub) = get_unification intruder_name intruder_state l_rec agent_name intruder_state lab in
 		let rec aux0 lab l_rec l =
		match l with [] -> ()
			|(label,value,entries,lst_choices)::ls ->
							(if(((exist_match=1 && l_rec<>(!value)) || l_rec="") && lab=label)
							then(
								List.iter (fun (entry,record,_) -> 
									Entry.delete_range entry ~start:(`Num 0) ~stop:`End;
									Entry.insert entry ~index:(`Num 0) ~text:(transcript_receiver_for_intruder agent_name l_rec);
									record:=l_rec;
								) (!entries);
								value:=l_rec;
							)
							else if((exist_match=1) && lab<>label)
							then (
								let unif_tmp = simul_affectation sub label in
								if(label<>unif_tmp)then(
									List.iter (fun (entry,record,lst) ->
										let find = ref false in
										let lst_contains = Listbox.get_range lst ~first:(`Num 0) ~last:`End in 
										Listbox.delete lst ~first:(`Num 0) ~last:`End;
										Listbox.insert lst ~index:`End 
										~texts:(remove "" 
											(List.map (fun c ->
												if((match_message intruder_name intruder_state (transcript_receiver_for_intruder agent_name c) agent_name intruder_state unif_tmp))
												then (if((!value)=(transcript_receiver_for_intruder agent_name c)) then find:=true ; c)
												else "")
											lst_contains
											));
										if not(!find) 
										then (
											value:="";
											record:="";
											Entry.delete_range entry ~start:(`Num 0) ~stop:`End;
										);
									) (!entries);
								);
							);
							aux0 lab l_rec ls);
		in
	aux0 lab l_rec l
	in
	List.iter
		(fun (label,_,entries,lst_choices) ->
			List.iter 
				(fun (_,_,lst) -> 
					Listbox.delete lst ~first:(`Num 0) ~last:`End; 
					Listbox.insert lst ~index:`End  
					~texts:(List.map (fun c -> (transcript_receiver_for_intruder agent_name c)) lst_choices)
				)
			(!entries)
		)
	(!l_entry);
	List.iter 
	(fun (label,value,_,_) -> 
		if(label<>lab && (!value)<>"") 
		then aux label (!value) (!l_entry) 
		else aux lab l_rec (!l_entry)
		) 
	(!l_entry);
 ;;
 let add_entry 	(intruder_name : string) (intruder_state : string) 
 		(agent_name : string) (label : string) 
		(e : Widget.entry Widget.widget) (l_rec : string Pervasives.ref) 
		(lst : Widget.listbox Widget.widget) (l0: string list) : unit=
  	let rec aux l =
		match l with [] -> l_entry:= ((label,ref "",ref [e,l_rec,lst],l0)::(!l_entry))
			|(lab,value,entries,_)::ls -> 	(if(lab=label)
							then	entries:=((e,l_rec,lst)::(!entries));
							aux ls);
	in aux (!l_entry);
	List.iter
	(fun (label,value,_,_) -> 
		if((!value)<>"")
		then update_entry intruder_name intruder_state agent_name label (!value)
	)
	(!l_entry);
	List.iter
	(fun (label,value,_,_) -> 
		if((!value)="")
		then update_entry intruder_name intruder_state agent_name label (!value)
	)
	(!l_entry);
 ;;  

 
 class box frame_root (intruder_name : string) (agent_name : string) (intruder_state : string) (message : string) (parent : box option) =
object(this)
  val mutable f = Frame.create frame_root
  val mutable f_left = Frame.create frame_root
  val mutable f_left_top = Frame.create frame_root
  val mutable f_left_down = Frame.create frame_root
  val mutable f_center = Frame.create frame_root
  val mutable f_center_top = Frame.create frame_root
  val mutable f_center_down = Frame.create frame_root
  val mutable l = Label.create ~text:"" frame_root
  val mutable entry_1 = Entry.create ~width:12 frame_root
  val mutable center_lst = Listbox.create ~width:10 ~background:selcol  ~selectmode:`Single frame_root
  val mutable center_lst_v = Scrollbar.create ~background:defcol ~orient:`Vertical  frame_root 
  val mutable decomp_message = []
  val mutable knowledge = []
  val mutable l0 = []
  val mutable l0_rec = ref "" 
  val mutable l_w = []
  val mutable is_an_atom = false
  val mutable click_i = (-1)
  
  method message_refinment boxRoot = (
  	if(is_an_atom || (car decomp_message)="inv")
	then (
	    	let label_1 = Label.create ~text:(transcript_receiver_for_intruder agent_name message) ~height:1 f_center_top in
	    	let l = Label.create ~text:"No match" ~foreground:violet ~width:7 ~background:selcol f_center_top in
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		pack ~side:`Top ~fill:`Both ~expand:false [f_center_top];
		pack ~side:`Top ~fill:`X ~expand:false [label_1];
		pack ~side:`Top ~fill:`Both ~expand:false [l];
		let button_unrefinment = Button.create ~text:"<" ~command:(fun () ->
	      		l0_rec := "" ; 
			(*update_entry intruder_name intruder_state agent_name message "";*)
			del_entry message entry_1;
	      		(match parent with None -> ()
	      		|Some p -> p#init);
	      		) f_center_top
		in
	 	(match parent with None -> ()
	      		|Some _ -> pack ~side:`Left ~fill:`X [button_unrefinment]);
	    )
	else 
  	if((car decomp_message)="pair")
	then ( 
		pack ~side:`Top ~fill:`Y ~expand:false [l];
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		let f_center_box = Frame.create f_center in
		pack ~side:`Left ~fill:`Y ~expand:true [f_center_box];
		let w1 = Some (new  box f_center_box intruder_name agent_name intruder_state (cadr decomp_message) boxRoot) in
			match w1 with None -> ()
				|Some obj_box -> obj_box#init;
		l_w <- w1::l_w;
		let frame_mark = Frame.create f_center in
		let label_vide = Label.create ~text:"." ~background:defcol ~foreground:blue frame_mark in
		let mark = Label.create ~text:"." ~background:defcol ~foreground:blue frame_mark in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_mark];
		pack ~side:`Top ~fill:`Y ~expand:false [label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [mark];
		let f_center_box2 = Frame.create f_center in
		pack ~side:`Left ~fill:`Y ~expand:true [f_center_box2];
		let w2 = Some (new  box f_center_box2 intruder_name agent_name intruder_state (caddr decomp_message) boxRoot) in
		match w2 with None -> ()
			|Some obj_box -> obj_box#init;
			l_w <- w2::l_w;
	)
	else if((car decomp_message)="scrypt" || (car decomp_message)="crypt")
	then (
		let col_par = getcol() in
		pack ~side:`Top ~fill:`Y ~expand:false [l];
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		let frame_left_par = Frame.create f_center in
		let left_par_label_vide = Label.create ~text:"{" ~foreground:violet ~background:col_par frame_left_par in
		let left_par = Label.create ~text:"{" ~foreground:violet ~background:col_par frame_left_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_left_par];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par];
		let f_center_box = Frame.create f_center in
		pack ~side:`Left ~fill:`Y ~expand:true [f_center_box];
		let w1 = Some (new  box f_center_box intruder_name agent_name intruder_state (caddr decomp_message) boxRoot) in
			match w1 with None -> ()
				|Some obj_box -> obj_box#init;
		l_w <- w1::l_w;
		let frame_right_par = Frame.create f_center in
		let right_par_label_vide = Label.create ~text:"}" ~foreground:violet ~background:col_par frame_right_par in
		let right_par = Label.create ~text:"}" ~foreground:violet ~background:col_par frame_right_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_right_par];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par];
		let frame_mark = Frame.create f_center in
		let label_vide = Label.create ~text:"_" ~background:defcol ~foreground:blue frame_mark in
		let mark = Label.create ~text:"_" ~background:defcol ~foreground:blue frame_mark in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_mark];
		pack ~side:`Top ~fill:`Y ~expand:false [label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [mark];
		let f_center_box2 = Frame.create f_center in
		pack ~side:`Left ~fill:`Y ~expand:true [f_center_box2];
		let w2 = Some (new  box f_center_box2 intruder_name agent_name intruder_state (cadr decomp_message) boxRoot) in
		match w2 with None -> ()
			|Some obj_box -> obj_box#init;
			l_w <- w2::l_w;
	)
	else if(((car decomp_message)="exp") || ((car decomp_message)="xor"))
	then (
		let col_par = getcol() in
		let label_vide1 = Label.create f_left_top ~text:(car decomp_message) ~background:defcol ~foreground:blue in
		Label.configure l ~text:(car decomp_message) ~background:defcol ~foreground:blue;
		pack ~side:`Top ~fill:`Y ~expand:true [f_left_top];
		pack ~side:`Top ~fill:`Y ~expand:false [label_vide1];
		pack ~side:`Top ~fill:`Y ~expand:false [l];
		pack ~side:`Top ~fill:`Y ~expand:true [f_left_down];
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		let frame_left_par = Frame.create f_center in
		let left_par_label_vide = Label.create ~text:"(" ~foreground:violet ~width:1 ~background:col_par frame_left_par in
		let left_par = Label.create ~text:"(" ~foreground:violet ~width:1 ~background:col_par frame_left_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_left_par];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par];
		let nb = ref (List.length decomp_message) in
		List.iter
		(fun m ->  
			let f_center_box = Frame.create f_center in
			pack ~side:`Left ~fill:`Y ~expand:true [f_center_box];
			let w1 = Some (new  box f_center_box intruder_name agent_name intruder_state m boxRoot) in
			match w1 with None -> ()
				|Some obj_box -> obj_box#init;
			l_w <- w1::l_w;
			if(!nb > 2) then(
				let frame_mark = Frame.create f_center in
				let label_vide2 = Label.create ~text:"," ~background:defcol ~foreground:blue frame_mark in
				let mark = Label.create ~text:"," ~background:defcol ~foreground:blue frame_mark in
				pack ~side:`Left ~fill:`Y ~expand:true [frame_mark];
				pack ~side:`Top ~fill:`Y ~expand:false [label_vide2];
				pack ~side:`Top ~fill:`Y ~expand:false [mark];
				nb:=(!nb)-1
			)
		)
		(cdr decomp_message);
		let frame_right_par = Frame.create f_center in
		let right_par_label_vide = Label.create ~text:")" ~foreground:violet ~background:col_par frame_right_par in
		let right_par = Label.create ~text:")" ~foreground:violet ~background:col_par frame_right_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_right_par];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par];   
	)
	else if ((car decomp_message)="apply")
	then(
		let col_par = getcol() in
		let label_vide1 = Label.create f_left_top ~text:(cadr decomp_message) ~background:violet ~foreground:violet in
		Label.configure l ~text:(cadr decomp_message) ~background:violet ~foreground:violet;
		pack ~side:`Top ~fill:`Y ~expand:true [f_left_top];
		pack ~side:`Top ~fill:`Y ~expand:false [label_vide1];
		pack ~side:`Top ~fill:`Y ~expand:false [l];
		pack ~side:`Top ~fill:`Y ~expand:true [f_left_down];
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		let frame_left_par = Frame.create f_center in
		let left_par_label_vide = Label.create ~text:"(" ~foreground:violet ~background:col_par frame_left_par in
		let left_par = Label.create ~text:"(" ~foreground:violet ~background:col_par frame_left_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_left_par];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par];
		let nb = ref (List.length decomp_message) in
		List.iter
		(fun m ->
			let f_center_box = Frame.create f_center in
			pack ~side:`Left ~fill:`Y ~expand:true [f_center_box];
	        	let w1 = Some (new  box f_center_box intruder_name agent_name intruder_state m boxRoot) in
			match w1 with None -> ()
				|Some obj_box -> obj_box#init;
			l_w <- w1::l_w;
			if(!nb > 3) then(
			let frame_mark = Frame.create f_center in
			let label_vide2 = Label.create frame_mark ~text:" " in
			let mark = Label.create ~text:"," ~background:defcol ~foreground:blue frame_mark in
			pack ~side:`Left ~fill:`Y ~expand:true [frame_mark];
			pack ~side:`Top ~fill:`Y ~expand:false [label_vide2];
			pack ~side:`Top ~fill:`Y ~expand:false [mark];
			nb:=(!nb)-1
			)
		)
		(cddr decomp_message);
		let frame_right_par = Frame.create f_center in
		let right_par_label_vide = Label.create ~text:")" ~foreground:violet ~background:col_par frame_right_par in
		let right_par = Label.create ~text:")" ~foreground:violet ~background:col_par frame_right_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_right_par];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par];
	    
	)
	else if((cdr decomp_message)<>[])
	then (
		let col_par = getcol() in
		pack ~side:`Top ~fill:`Y ~expand:false [l];
		pack ~side:`Left ~fill:`Y ~expand:true [f_center];
		
		let w1 = Some (new  box f_center intruder_name agent_name intruder_state (car decomp_message) boxRoot) in
		match w1 with None -> ()
			|Some obj_box -> obj_box#init;
		l_w <- w1::l_w;
		let frame_left_par = Frame.create f_center in
		let left_par_label_vide = Label.create ~text:"(" ~foreground:col_par ~background:clicol frame_left_par in
		let left_par = Label.create ~text:"(" ~foreground:col_par ~background:clicol frame_left_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_left_par];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [left_par];
		let nb = ref (List.length decomp_message) in
		List.iter
		(fun m ->  
			let f_center_box = Frame.create f_center in
			pack ~side:`Left ~fill:`Y ~expand:true [f_center_box];
			let w1 = Some (new  box f_center_box intruder_name agent_name intruder_state m boxRoot) in
			match w1 with None -> ()
				|Some obj_box -> obj_box#init;
			l_w <- w1::l_w;
			if(!nb > 2) then(
				let frame_mark = Frame.create f_center in
				let label_vide2 = Label.create frame_mark ~text:" " in
				let mark = Label.create ~text:"," ~background:defcol ~foreground:blue frame_mark in
				pack ~side:`Left ~fill:`Y ~expand:true [frame_mark];
				pack ~side:`Top ~fill:`Y ~expand:false [label_vide2];
				pack ~side:`Top ~fill:`Y ~expand:false [mark];
				nb:=(!nb)-1
			)
		)
		(cdr decomp_message);
		let frame_right_par = Frame.create f_center in
		let right_par_label_vide = Label.create ~text:")" ~foreground:col_par ~background:clicol frame_right_par in
		let right_par = Label.create ~text:")" ~foreground:col_par ~background:clicol frame_right_par in
		pack ~side:`Left ~fill:`Y ~expand:true [frame_right_par];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par_label_vide];
		pack ~side:`Top ~fill:`Y ~expand:false [right_par];   
	);
  )

  method init = (
    	(this)#destroy;
  	f <- Frame.create frame_root;
	f_left <- Frame.create f;
	f_left_top <- Frame.create f_left;
	f_left_down <- Frame.create f_left;
	f_center <- Frame.create f;
	f_center_top <- Frame.create f_center;
	f_center_down <- Frame.create f_center;
	l <- Label.create ~text:"" f_left_top;
	entry_1 <- Entry.create ~width:12 f_center_top ~background:selcol ;
	center_lst <- Listbox.create ~width:10 ~background:selcol  ~selectmode:`Single f_center_down;
	center_lst_v <- Scrollbar.create ~background:blue_light ~orient:`Vertical  ~borderwidth:1 f_center_down;
	
	pack ~side:`Left ~fill:`Both ~expand:true [f];
	pack ~side:`Left ~fill:`Y ~expand:true [f_left];
        if(intruder_name<>"" && agent_name<>"" && intruder_state<>"")
	then( 
          decomp_message <- (decompose message);

          knowledge <- (let tmp = decompose(get_value_of_var "x" "set_knowledge") in
			  if(tmp<>[]) 
			  then (cdr tmp)
			  else []);

	  let rec aux e l res =
	    match l with [] -> List.rev res
	      |(x::ls) -> if(match_message intruder_name intruder_state x agent_name intruder_state e)
			then aux e ls (x::res)
			else aux e ls res;
	  in
	    l0 <- (aux message knowledge []);
	    
	    if(decomp_message <> []) then is_an_atom <- false
	    else  if((is_a_var message) || (is_a_value message)) then (is_an_atom <- true);
	    
	    if(l0<>[])
	    then(
	    	let label_1 = Label.create ~text:(transcript_receiver_for_intruder agent_name message) f_center_top in
	      	let f_center_button = Frame.create f_center in
		let button_unrefinment = Button.create ~text:"<" ~command:(fun () ->
	      		l0_rec := "" ; 
			(*update_entry intruder_name intruder_state agent_name message "";*)
			del_entry message entry_1;
	      		(match parent with None -> ()
	      		|Some p -> p#init);
	      		) f_center_button 
		in
	 	(match parent with None -> ()
	      		|Some _ -> pack ~side:`Left ~fill:`X [button_unrefinment]);
	      let button_clear = Button.create ~text:"Clear" ~command:(fun () -> l0_rec := "" ; update_entry intruder_name intruder_state agent_name message "") f_center_button in
	      let button_refinment = Button.create ~text:">" ~command:(fun () -> 
	      	l0_rec := "" ; 
		update_entry intruder_name intruder_state agent_name message "";
		destroy label_1;
		destroy button_unrefinment;
		destroy button_clear;
		destroy f_center_button;
		del_entry message entry_1;
		destroy entry_1;
		destroy f_center_top;
		destroy f_center_down;
		destroy center_lst_v;
		destroy center_lst;
		destroy f_center_button;
		destroy l;
		destroy f_left_top;
		destroy f_left_down;
		
		f_left_top <- Frame.create f_left;
		f_left_down <- Frame.create f_left;
		f_center_top <- Frame.create f_center;
		f_center_down <- Frame.create f_center;
		l <- Label.create ~text:"" f_left_top;
		entry_1 <- Entry.create ~width:12 f_center_top ~background:selcol ;
		center_lst <- Listbox.create ~width:10 ~background:selcol  ~selectmode:`Single f_center_down;
		center_lst_v <- Scrollbar.create ~background:blue_light ~orient:`Vertical  ~borderwidth:1 f_center_down;
		(this)#message_refinment (Some (this :> box));	      	
	      ) f_center_button in
	      scroll_link center_lst_v center_lst "vertical";
	      pack ~side:`Left ~fill:`Y ~expand:true [f_center];
	      pack ~side:`Top ~fill:`Y ~expand:false [f_center_top];
	      pack ~side:`Top ~fill:`Y ~expand:false [label_1];
	      pack ~side:`Top ~fill:`X ~expand:true [entry_1];
	      pack ~side:`Top ~fill:`Both ~expand:true [f_center_down];
	      pack ~side:`Right ~fill:`Y [center_lst_v];
	      pack ~side:`Top ~fill:`Both ~expand:true [center_lst];
	      pack ~side:`Bottom ~fill:`X [f_center_button];
	      pack ~side:`Left ~fill:`X [button_clear];
	      if not(is_an_atom) then pack ~side:`Left ~fill:`X [button_refinment];
	    
	      Listbox.insert center_lst ~index:(`Num 0)~texts:(List.map (fun m -> transcript_receiver_for_intruder agent_name m) l0);
	      Entry.configure entry_1 ~width:(max 12 (3+(max_length_string(Listbox.get_range center_lst ~first:(`Num 0) ~last:`End))));
	      add_entry intruder_name intruder_state agent_name message entry_1 l0_rec center_lst l0;
	      
	      bind center_lst
	      ~events:[(`ButtonPressDetail 1)]
	      ~fields:[`MouseY]
	      ~action:(function x -> 
				  let result = 
				    Listbox.nearest 
				      center_lst
				    ~y:x.ev_MouseY
				  in
				  let select = (* obtain the integer from the [`Num of int] *)
				    match result with
				      | `Num num -> num
				  in
			            if(click_i=select)
				    then(
					l0_rec := transcript_receiver_for_intruder agent_name (Listbox.get center_lst ~index:(`Num select));
					update_entry intruder_name intruder_state agent_name message (!l0_rec);
					click_i <- (-1)
				    )
				    else click_i <- select;
			       );
	      
	    )
	    else (this)#message_refinment None
	);	    
  )

  method destroy = (
	destroy l;
	destroy f_left_top;
	destroy f_left_down;
	destroy f_left;
	del_entry message entry_1;
	destroy entry_1;
	List.iter
	(fun w1 ->
	match w1 with None -> ()
		| Some obj_box -> obj_box#destroy;)
	l_w;
	l_w <- [];
	destroy center_lst;
	destroy center_lst_v;
	destroy f_center_top;
	destroy f_center_down;
	destroy f_center;
	destroy f;
	l0_rec:="";
  )


  method get_choice = (
	if(l_w=[]) then (
		!l0_rec
	)
	else (
	let l_m = List.map
			(fun w1 -> match w1 with None -> ""
				| Some obj_box -> obj_box#get_choice)
			(List.rev l_w)
	in 
	if(List.mem "" l_m) then ""
	else if(l_m=[]) then ""
	else if(((car decomp_message)="scrypt") || ((car decomp_message)="crypt"))
	then ((car decomp_message)^"("^(cadr l_m)^","^(car l_m)^")")
	else ((car decomp_message)^"("^(list2string "," l_m)^")")
	)
 )

end;;
(** Open a window for compose a message to adding to the knowledge of the intruder composed with his knoewledge.
Thi function is called by the button "label_intruder" in interface.ml
*)
 let window_compose_intruder_knowledge 	(root : Widget.toplevel Widget.widget) 
 					(trace_story : string list ref)
					(incomming_events : string list ref)
					(insert_lst : string -> string -> unit) 
					(display_intruder_knowledge : unit -> unit) : unit =
	Hashtbl.clear transcript_table_for_intruder;
	let root_var =  Toplevel.create ~borderwidth:1 ~relief:`Groove root in
	Wm.title_set root_var "Compose an intruder knowledge";
	let var_button_iFrame = Frame.create ~width:60 root_var in
	
	let assist_iCanvas = Canvas.create ~width:60 ~height:275 ~borderwidth:2 ~relief:`Ridge ~scrollregion:(-5000,0,5000,0) root_var in
	let assist_iFrame = Frame.create ~width:60 ~height:278 assist_iCanvas in
	let assist_iCanvas_h = Scrollbar.create ~background:defcol ~orient:`Horizontal root_var in
 		scroll_link_canvas assist_iCanvas_h assist_iCanvas "horizontal";	
	ignore(Canvas.create_window assist_iCanvas ~window:assist_iFrame ~x:490 ~y:138 ~anchor:`Center);
						
	let lst_iFrame = Frame.create ~width:50 root_var in
	let iLabel = Label.create ~text:"Compose :" var_button_iFrame in
	let lst_iFrame2 = Frame.create (* ~width:50 *) ~height:20 lst_iFrame in
	let lst_iFrame2_top = Frame.create (* ~width:20 *) ~height:20 lst_iFrame2 in
	let iLabel1 = Label.create lst_iFrame2_top ~width:6 ~text:"" ~background:defcol in
	let iLabel2 = Entry.create lst_iFrame2_top ~width:compose_intruder_entry_width ~background:selcol in
	let iLabel3 = Label.create lst_iFrame2_top ~width:1 ~text:"." ~background:defcol in
	let iLabel4 = Entry.create lst_iFrame2_top ~width:compose_intruder_entry_width ~background:selcol in

	let lst_iFrame2_down = Frame.create ~width:compose_intruder_choices_list_width ~height:20 lst_iFrame2 in
	let button_add = Button.create lst_iFrame2_top ~text:"Add :" in

	let receive_lst = Listbox.create ~width:compose_intruder_choices_list_width ~height:10 ~background:selcol  ~selectmode:`Single lst_iFrame2_down in
	let receive_v = Scrollbar.create ~background:defcol ~orient:`Vertical  lst_iFrame2_down in
	let receive_h = Scrollbar.create ~background:defcol ~orient:`Horizontal  lst_iFrame2_down in
  		scroll_link receive_v receive_lst "vertical";
 		scroll_link receive_h receive_lst "horizontal";	
	
	
	let confirmFrame = Frame.create root_var in
	let viLabel2 = ref "" in
	let viLabel4 = ref "" in
	let tvi = Textvariable.create () in
	Textvariable.set tvi "pair";
	let irads = 	List.map 
			(fun (t, v) -> (Radiobutton.create ~text:t ~value:v ~variable:tvi ~borderwidth:1 ~command:(fun () -> (
				let tmp = Textvariable.get tvi in
				if(tmp="pair") then (Label.configure iLabel1 ~text:"" ; Label.configure iLabel3 ~text:"." )
				else if(tmp="scrypt") then (Label.configure iLabel1 ~text:"" ; Label.configure iLabel3 ~text:"_" )
				else if(tmp="exp") then (Label.configure iLabel1 ~text:"Exp" ; Label.configure iLabel3 ~text:", " )
				else if(tmp="xor") then (Label.configure iLabel1 ~text:"Xor" ; Label.configure iLabel3 ~text:", " )
			)) var_button_iFrame)) 
			[("Pair", "pair") ; ("Scrypt", "scrypt") ; ("Exp", "exp") ; ("Xor", "xor")] in

     	match irads with []          -> ();
                     |[x]       -> ();
                     |(x::y::_) -> Radiobutton.select x;
	let lst_iFrame1 = Frame.create ~width:50 lst_iFrame in
	let cintruder_knowledge_lst = Listbox.create ~width:compose_intruder_list_width ~height:10 ~background:clicol  ~selectmode:`Single lst_iFrame1 in
	let cintruder_knowledge_v = Scrollbar.create ~background:violet ~orient:`Vertical  lst_iFrame1 in
	let cintruder_knowledge_h = Scrollbar.create ~background:violet ~orient:`Horizontal  lst_iFrame1 in
  		scroll_link cintruder_knowledge_v cintruder_knowledge_lst "vertical";
 		scroll_link cintruder_knowledge_h cintruder_knowledge_lst "horizontal";
	
	let lst_iFrame3 = Frame.create ~width:50 ~height:20 lst_iFrame in	
	let cintruder_knowledge_lst3 = Listbox.create ~width:compose_intruder_list_width ~height:10 ~background:clicol  ~selectmode:`Single lst_iFrame3 in
	let cintruder_knowledge_v3 = Scrollbar.create ~background:violet ~orient:`Vertical  lst_iFrame3 in
	let cintruder_knowledge_h3 = Scrollbar.create ~background:violet ~orient:`Horizontal  lst_iFrame3 in
  		scroll_link cintruder_knowledge_v3 cintruder_knowledge_lst3 "vertical";
 		scroll_link cintruder_knowledge_h3 cintruder_knowledge_lst3 "horizontal";
		
			
	let display_intruder_knowledge_compose () =
		Listbox.delete cintruder_knowledge_lst ~first:(`Num 0) ~last:`End;
		Listbox.delete cintruder_knowledge_lst3 ~first:(`Num 0) ~last:`End;
		let knowledge = let tmp = decompose(get_value_of_var "x" "set_knowledge") in
				if(tmp<>[]) then (cdr tmp)
				else []
		in
		let lt = List.map transcript_sender knowledge in
		Listbox.insert cintruder_knowledge_lst ~index:`End ~texts:lt; 
		Listbox.insert cintruder_knowledge_lst3 ~index:`End ~texts:lt in
	
	let f_widget k =
		if(k<>"")
		then( 
			add_in_set "(Intruder_, 0)" k "(Intruder_, 0)" "Set_knowledge" ;
			update_intruder_knowledge ();
			
			trace_story := ("add_in_set((Intruder_, 0),"^k^",(Intruder_, 0),Set_knowledge)")::(!trace_story);
			display_intruder_knowledge_compose ();
		)
	in
		
	let assist = ref (new box assist_iFrame "" "" "" "" None) in
	let button_add_frame = Button.create root_var ~text:"Add messages composed with this pattern :" 
	~command:(fun () -> f_widget (!assist)#get_choice; 
	display_intruder_knowledge (); 
	insert_lst "" "";) ~width:68 in
	Button.configure button_add ~command:(fun () ->
		if(((Entry.get iLabel2)<>"") && ((Entry.get iLabel4)<>"")) 
		then (
			let add_k = 	if ((Textvariable.get tvi)="pair" || (Textvariable.get tvi)="exp" || (Textvariable.get tvi)="xor") 
					then ((Textvariable.get tvi)^"("^(transcript_sender (!viLabel2))^","^(transcript_sender (!viLabel4))^")")
					else ((Textvariable.get tvi)^"("^(transcript_sender (!viLabel4))^","^(transcript_sender (!viLabel2))^")")
			in
			add_in_set "(Intruder_, 0)" add_k "(Intruder_, 0)" "Set_knowledge"; 
			trace_story := ("add_in_set((Intruder_, 0),"^add_k^",(Intruder_, 0),Set_knowledge)")::(!trace_story);
			update_intruder_knowledge ();
			display_intruder_knowledge_compose ();
			display_intruder_knowledge ();
			index_col:=0;
			l_entry := [];
			(!assist)#init;
			insert_lst "" "";
			);
	);		
	
	let buttonOk = Button.create ~text:"Ok" confirmFrame ~command:(fun () -> (
		let lock_update = ref false in
		if(((Entry.get iLabel2)<>"") && ((Entry.get iLabel4)<>"")) 
		then (
			let add_k = 	if ((Textvariable.get tvi)="pair" || (Textvariable.get tvi)="exp" || (Textvariable.get tvi)="xor") 
					then ((Textvariable.get tvi)^"("^(transcript_sender (!viLabel2))^","^(transcript_sender (!viLabel4))^")")
					else ((Textvariable.get tvi)^"("^(transcript_sender (!viLabel4))^","^(transcript_sender (!viLabel2))^")")
			in
			add_in_set "(Intruder_, 0)" add_k "(Intruder_, 0)" "Set_knowledge"; 
			trace_story := ("add_in_set((Intruder_, 0),"^add_k^",(Intruder_, 0),Set_knowledge)")::(!trace_story);
			lock_update := true
			);
		let add_k2 = ((!assist)#get_choice) in
		if(add_k2<>"")then(
			add_in_set "(Intruder_, 0)" add_k2 "(Intruder_, 0)" "Set_knowledge" ;
			trace_story := ("add_in_set((Intruder_, 0),"^add_k2^",(Intruder_, 0),Set_knowledge)")::(!trace_story);
			lock_update := true
			);
		if (!lock_update) then (update_intruder_knowledge ();	display_intruder_knowledge ();	insert_lst "" "");
		destroy confirmFrame;		
		destroy lst_iFrame3;
		destroy cintruder_knowledge_v3;
		destroy cintruder_knowledge_h3;
		destroy cintruder_knowledge_lst3;
		destroy lst_iFrame3;
		destroy iLabel1;
		destroy iLabel2;
		destroy iLabel3;
		destroy iLabel4;
		destroy button_add;
		destroy lst_iFrame2_top;
		destroy receive_v;
		destroy receive_h;
		destroy receive_lst;
		destroy lst_iFrame2_down;
		destroy lst_iFrame2;
		destroy cintruder_knowledge_lst;
		destroy cintruder_knowledge_h;
		destroy cintruder_knowledge_v;
		destroy lst_iFrame1;		
		destroy lst_iFrame;
		List.iter destroy irads;
		destroy iLabel;
		(!assist)#destroy;
		destroy button_add_frame;
		destroy assist_iFrame;
		destroy var_button_iFrame;
		destroy root_var;
	)) in
	
	let buttonCancel = Button.create ~text:"Cancel" confirmFrame ~command:(fun () -> (
		destroy confirmFrame;
		destroy buttonOk;	
		destroy lst_iFrame3;
		destroy cintruder_knowledge_v3;
		destroy cintruder_knowledge_h3;
		destroy cintruder_knowledge_lst3;
		destroy lst_iFrame3;
		destroy iLabel1;
		destroy iLabel2;
		destroy iLabel3;
		destroy iLabel4;
		destroy button_add;
		destroy lst_iFrame2_top;
		destroy receive_v;
		destroy receive_h;
		destroy receive_lst;
		destroy lst_iFrame2_down;
		destroy lst_iFrame2;
		destroy cintruder_knowledge_lst;
		destroy cintruder_knowledge_h;
		destroy cintruder_knowledge_v;
		destroy lst_iFrame1;		
		destroy lst_iFrame;
		List.iter destroy irads;
		destroy iLabel;
		(!assist)#destroy;
		destroy button_add_frame;
		destroy assist_iFrame;
		destroy var_button_iFrame;
		destroy root_var;
	)) in
	
	let all_actions = ref [] in
	List.iter (fun e -> 
		let (_, ag2, action0) = actionTreatment e in
		let action = 	let decomp = decompose action0 in
				if(decomp<>[]) then (car decomp) else ""
		in
		if("(Intruder_, 0)"<>ag2) then(
			let message_receive = 
				let decomp = decompose action in
				if(decomp<>[]) then  (transcript_receiver_for_intruder ag2 (caddr decomp)) else "";		
			in
			if(not(List.mem (ag2,message_receive) (!all_actions)) && message_receive<>"")
			then( 
				all_actions:=((ag2,message_receive)::(!all_actions));
				Listbox.insert receive_lst ~index:(`Num 0)~texts:[ag2^" can receive : "^message_receive^" - type : "^(transcript_receiver (get_type_of_var_in_state ag2 "x" message_receive))];
			);
		);
	) (!incomming_events);
	(
	let lock = ref false in
	List.iter
	(fun (name2,id2,statesL2,actionsL2) ->
		let ag2 = (get_name_in_session name2 id2) in
		if(ag2<>"(Intruder_, 0)")
		then(
			let prefix = (ag2^" can receive : ") in
			List.iter
			(fun (state2,exec2) ->
			if(operations_test_treatment_right ag2 state2)
			then( 
		
				List.iter
        			(fun (initial2,_,final2) ->
					if((findIknows initial2)<>"") 
					then(
						lock:=false;
						local_variable_change:=[];
						if(state2<>(findState initial2) && match_state ag2 state2 ag2 (findState initial2))
						then(ignore(assign_var_of_state ag2 state2 (get_name_in_session name2 id2) (findState initial2)) ; clear_message_story () ; lock:=true; );
        					if(
						(( ( (!exec2)=false || ((findIknows initial2) = "") )
						&& (rcv_stack_is_empty ag2 state2)) || (List.mem (findIknows initial2)(get_rcv_stack ag2 state2)))
						&& ((!lock) || state2=(findState initial2) || (match_state ag2 state2 ag2 (findState initial2))
						|| state2="" ) )
						then 
						(
							let ic0 = transcript_receiver_for_intruder ag2 (findIknows initial2) in
							let ic = prefix^ic0 in
							if(not(List.mem (ag2,ic0) (!all_actions)) && ic0<>"")
							then( 	all_actions:=((ag2,ic0)::(!all_actions));
								Listbox.insert receive_lst ~index:(`Num 0)~texts:[ic^" - type : "^(transcript_receiver (get_type_of_var_in_state ag2 (findState initial2) (findIknows initial2)))]);
						);
						if(!lock) then	(previous_message_story () ; remove_local_variable_change() );
					)
				)actionsL2;
		
		 	);
			)(!statesL2)
		)
   	)(!automate)
	);
	
	pack ~side:`Top ~fill:`Y ~expand:false [var_button_iFrame];
	pack ~side:`Left ~fill:`X ~expand:true [iLabel];
	pack ~side:`Left ~fill:`X ~expand:true irads;
	pack ~side:`Left ~fill:`Both ~expand:false [button_add];
	

	pack ~side:`Top ~fill:`Both ~expand:true [lst_iFrame];
	pack ~side:`Left ~fill:`Y ~expand:false [lst_iFrame1];
	pack ~side:`Left ~fill:`Y [cintruder_knowledge_v];
	pack ~side:`Bottom ~fill:`X [cintruder_knowledge_h];
	pack ~side:`Top ~fill:`Both ~expand:true [cintruder_knowledge_lst];
	pack ~side:`Left ~fill:`Both ~expand:true [lst_iFrame2];
	
	pack ~side:`Top ~fill:`X ~expand:true [lst_iFrame2_top];
	pack ~side:`Top ~fill:`Both ~expand:true [lst_iFrame2_down];

(* 	pack ~side:`Top ~fill:`Both ~expand:true [lst_iFrame2_down]; *)

	pack ~side:`Right ~fill:`Y [receive_v];
	pack ~side:`Bottom ~fill:`X [receive_h];
	pack ~side:`Top ~fill:`Both ~expand:true [receive_lst];
	
	pack ~side:`Left ~fill:`Both ~expand:false [iLabel1];
	pack ~side:`Left ~fill:`Both ~expand:true [iLabel2];
	pack ~side:`Left ~fill:`Both ~expand:false [iLabel3];
	pack ~side:`Left ~fill:`Both ~expand:true [iLabel4];

	pack ~side:`Left ~fill:`Both ~expand:true [lst_iFrame3];
	pack ~side:`Right ~fill:`Y [cintruder_knowledge_v3];
	pack ~side:`Bottom ~fill:`X [cintruder_knowledge_h3];
	pack ~side:`Top ~fill:`Both ~expand:true [cintruder_knowledge_lst3];
	pack ~side:`Left ~fill:`Y ~expand:false [lst_iFrame3];
		
	pack ~side:`Bottom ~fill:`X ~expand:false [confirmFrame];
	pack ~side:`Left ~fill:`X ~expand:true [buttonOk];
	pack ~side:`Left ~fill:`X ~expand:true [buttonCancel];
	
	
	display_intruder_knowledge_compose ();
	
	let click_i = ref (-1) in
	bind cintruder_knowledge_lst
		  ~events:[(`ButtonPressDetail 1)]
		  ~fields:[`MouseY]
		  ~action:(function x -> 
			     let result = 
			       Listbox.nearest 
				 cintruder_knowledge_lst
			       ~y:x.ev_MouseY
			     in
			     let select = (* obtain the integer from the [`Num of int] *)
			       match result with
				 | `Num num -> num
			     in 
			        if((!click_i)=select)
				then(
				viLabel2 := Listbox.get cintruder_knowledge_lst ~index:(`Num select);
				Entry.delete_range iLabel2 ~start:(`Num 0) ~stop:`End;
				Entry.insert iLabel2 ~index:(`Num 0) ~text:(!viLabel2);
				click_i := (-1)
				)
				else click_i := select;
			);
	bind cintruder_knowledge_lst3
		  ~events:[(`ButtonPressDetail 1)]
		  ~fields:[`MouseY]
		  ~action:(function x -> 
			     let result = 
			       Listbox.nearest 
				 cintruder_knowledge_lst3
			       ~y:x.ev_MouseY
			     in
			     let select = (* obtain the integer from the [`Num of int] *)
			       match result with
				 | `Num num -> num
			     in
			        if((!click_i)=select)
				then(
				viLabel4 := Listbox.get cintruder_knowledge_lst3 ~index:(`Num select);
				Entry.delete_range iLabel4 ~start:(`Num 0) ~stop:`End;
				Entry.insert iLabel4 ~index:(`Num 0) ~text:(!viLabel4);
				click_i := (-1)
				)
				else click_i := select;
			);
				
	bind receive_lst
		  ~events:[(`ButtonPressDetail 1)]
		  ~fields:[`MouseY]
		  ~action:(function x -> 
			     let result = 
			       Listbox.nearest 
				 receive_lst
			       ~y:x.ev_MouseY
			     in
			     let select = (* obtain the integer from the [`Num of int] *)
			       match result with
				 | `Num num -> num
			     in 
			        if((!click_i)=select)
				then(
				let receive = List.nth (!all_actions) select in
				(!assist)#destroy;
				assist := new box assist_iFrame "(Intruder_, 0)" (fst receive) "x" (transcript_receiver_for_intruder (fst receive) (snd receive)) None;
				index_col:=0;
				l_entry := [];
				(!assist)#init;
				pack ~side:`Top ~fill:`Y ~expand:false [button_add_frame];
				pack ~side:`Top ~fill:`Both ~expand:false [assist_iCanvas];
				pack ~side:`Top ~fill:`X [assist_iCanvas_h];
				click_i := (-1);
				
				)
				else click_i := select;
			);			

