
(* SPAN - A Security Protocol Animator
   Copyright (C) 2006-2009 Yann Glouche, Thomas Genet, Olivier Heen, 
   	     	 	   Erwan Houssay and Ronan Saillard.

   The CAS+ Parser includes source code from the CASRUL tool
   CASRUL: Copyright (C) 2001 Florent Jacquemard, Michael Rusinowitch and
      		    	      Laurent Vigneron.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License version 2, as
   published by the Free Software Foundation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

   See the GNU Library General Public License version 2 for more details
   (enclosed in the file LGPL).


   Version 1.6. Last modification 16/07/09
*)
type token =
  | VAR_IDENT of (string)
  | CONST_IDENT of (string)
  | NAT_IDENT of (string)
  | ROLE
  | INIT
  | ACCEPT
  | IKNOWLEDGE
  | END
  | LOCAL
  | OWNS
  | CONST
  | CONS
  | DELETE
  | NEW
  | TRANSITION
  | GOAL
  | LOOP
  | AND
  | PRIME
  | UNDERSCORE
  | IMPLIES
  | OR
  | LTL_op1
  | LTL_op2
  | LTL_op3
  | LTL_op4
  | LTL_op5
  | AGENT
  | CHANNEL
  | PUBLIC_KEY
  | TEXT
  | MESSAGE
  | HASH
  | HASH_FUNC
  | NAT
  | PROTOCOL_ID
  | BOOL
  | SYMMETRIC_KEY
  | IN
  | NOT
  | ACTION_ARROW
  | REACTION_ARROW
  | FUNCTION_ARROW
  | L_PAR
  | R_PAR
  | L_BRACE
  | R_BRACE
  | COMMA
  | COLON
  | SEMI_COLON
  | DOT
  | DEF_EQUAL
  | PLUS
  | EQUAL
  | ASSIGN
  | LEQ
  | NEQ
  | PLAYED_BY
  | COMPOSITION
  | SECRECY_OF
  | AUTHENTICATES
  | AUTHENTICATION_ON
  | WEAKLY
  | WEAK_AUTHENTICATION_ON
  | ON
  | DY
  | OTA
  | SET
  | INV
  | START

open Parsing;;
# 2 "parser.mly"
open Lexing;;
open Types;;
open Globals;;
open Error_handler;;
open Semantic_check;;


let parse_error msg =
  handleParseError();
  exit(-1)
;;

let newSetsInfo = ref [];;
let newSetsInit = ref [];;
let newSetsDecl = ref [];;

let line_number () =
  string_of_int !Error_handler.lineCounter
;;
# 95 "parser.ml"
let yytransl_const = [|
  260 (* ROLE *);
  261 (* INIT *);
  262 (* ACCEPT *);
  263 (* IKNOWLEDGE *);
  264 (* END *);
  265 (* LOCAL *);
  266 (* OWNS *);
  267 (* CONST *);
  268 (* CONS *);
  269 (* DELETE *);
  270 (* NEW *);
  271 (* TRANSITION *);
  272 (* GOAL *);
  273 (* LOOP *);
  274 (* AND *);
  275 (* PRIME *);
  276 (* UNDERSCORE *);
  277 (* IMPLIES *);
  278 (* OR *);
  279 (* LTL_op1 *);
  280 (* LTL_op2 *);
  281 (* LTL_op3 *);
  282 (* LTL_op4 *);
  283 (* LTL_op5 *);
  284 (* AGENT *);
  285 (* CHANNEL *);
  286 (* PUBLIC_KEY *);
  287 (* TEXT *);
  288 (* MESSAGE *);
  289 (* HASH *);
  290 (* HASH_FUNC *);
  291 (* NAT *);
  292 (* PROTOCOL_ID *);
  293 (* BOOL *);
  294 (* SYMMETRIC_KEY *);
  295 (* IN *);
  296 (* NOT *);
  297 (* ACTION_ARROW *);
  298 (* REACTION_ARROW *);
  299 (* FUNCTION_ARROW *);
  300 (* L_PAR *);
  301 (* R_PAR *);
  302 (* L_BRACE *);
  303 (* R_BRACE *);
  304 (* COMMA *);
  305 (* COLON *);
  306 (* SEMI_COLON *);
  307 (* DOT *);
  308 (* DEF_EQUAL *);
  309 (* PLUS *);
  310 (* EQUAL *);
  311 (* ASSIGN *);
  312 (* LEQ *);
  313 (* NEQ *);
  314 (* PLAYED_BY *);
  315 (* COMPOSITION *);
  316 (* SECRECY_OF *);
  317 (* AUTHENTICATES *);
  318 (* AUTHENTICATION_ON *);
  319 (* WEAKLY *);
  320 (* WEAK_AUTHENTICATION_ON *);
  321 (* ON *);
  322 (* DY *);
  323 (* OTA *);
  324 (* SET *);
  325 (* INV *);
  326 (* START *);
    0|]

let yytransl_block = [|
  257 (* VAR_IDENT *);
  258 (* CONST_IDENT *);
  259 (* NAT_IDENT *);
    0|]

let yylhs = "\255\255\
\001\000\003\000\003\000\006\000\006\000\007\000\011\000\008\000\
\009\000\018\000\021\000\021\000\024\000\024\000\012\000\029\000\
\029\000\040\000\041\000\041\000\031\000\031\000\043\000\033\000\
\033\000\045\000\046\000\046\000\035\000\035\000\049\000\049\000\
\050\000\050\000\050\000\056\000\056\000\057\000\057\000\059\000\
\059\000\037\000\037\000\061\000\039\000\039\000\064\000\064\000\
\014\000\014\000\070\000\070\000\073\000\073\000\074\000\074\000\
\063\000\063\000\080\000\080\000\080\000\080\000\080\000\078\000\
\078\000\078\000\078\000\083\000\083\000\083\000\083\000\083\000\
\077\000\077\000\079\000\086\000\086\000\086\000\086\000\086\000\
\017\000\017\000\091\000\091\000\091\000\091\000\092\000\092\000\
\094\000\094\000\094\000\095\000\095\000\095\000\098\000\098\000\
\096\000\005\000\099\000\099\000\004\000\004\000\100\000\101\000\
\101\000\102\000\102\000\102\000\102\000\102\000\102\000\106\000\
\106\000\106\000\106\000\106\000\106\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\107\000\107\000\
\107\000\107\000\109\000\109\000\109\000\109\000\025\000\044\000\
\044\000\113\000\113\000\115\000\115\000\115\000\115\000\115\000\
\115\000\115\000\117\000\117\000\117\000\047\000\104\000\104\000\
\118\000\118\000\120\000\120\000\116\000\116\000\116\000\116\000\
\116\000\116\000\116\000\116\000\116\000\116\000\116\000\116\000\
\116\000\122\000\122\000\122\000\122\000\082\000\082\000\082\000\
\082\000\082\000\082\000\084\000\084\000\084\000\084\000\084\000\
\084\000\084\000\084\000\084\000\084\000\084\000\084\000\055\000\
\055\000\085\000\085\000\085\000\089\000\089\000\053\000\053\000\
\053\000\053\000\053\000\053\000\053\000\053\000\053\000\124\000\
\124\000\124\000\124\000\124\000\124\000\124\000\124\000\124\000\
\124\000\124\000\124\000\124\000\088\000\088\000\129\000\129\000\
\129\000\129\000\129\000\131\000\131\000\131\000\131\000\131\000\
\130\000\130\000\110\000\110\000\127\000\127\000\127\000\002\000\
\071\000\093\000\015\000\019\000\103\000\027\000\097\000\119\000\
\114\000\068\000\066\000\112\000\022\000\030\000\028\000\034\000\
\036\000\069\000\072\000\075\000\060\000\020\000\062\000\081\000\
\087\000\111\000\065\000\051\000\105\000\090\000\013\000\016\000\
\054\000\058\000\052\000\123\000\125\000\128\000\067\000\126\000\
\038\000\010\000\121\000\026\000\042\000\048\000\032\000\023\000\
\076\000\000\000"

let yylen = "\002\000\
\004\000\001\000\002\000\001\000\001\000\010\000\003\000\008\000\
\007\000\002\000\001\000\000\000\002\000\004\000\014\000\002\000\
\000\000\001\000\002\000\004\000\002\000\000\000\001\000\002\000\
\000\000\001\000\002\000\004\000\002\000\000\000\001\000\003\000\
\005\000\005\000\007\000\001\000\009\000\001\000\004\000\002\000\
\005\000\002\000\000\000\002\000\001\000\000\000\009\000\007\000\
\004\000\002\000\002\000\003\000\009\000\009\000\001\000\001\000\
\002\000\005\000\001\000\005\000\007\000\007\000\007\000\002\000\
\002\000\005\000\005\000\001\000\007\000\007\000\006\000\007\000\
\002\000\004\000\001\000\007\000\011\000\005\000\007\000\007\000\
\004\000\002\000\002\000\004\000\004\000\005\000\001\000\009\000\
\002\000\004\000\005\000\002\000\004\000\005\000\002\000\005\000\
\001\000\008\000\001\000\000\000\001\000\000\000\004\000\001\000\
\002\000\008\000\009\000\003\000\003\000\003\000\002\000\001\000\
\002\000\002\000\002\000\002\000\005\000\001\000\002\000\002\000\
\002\000\002\000\003\000\003\000\003\000\005\000\005\000\007\000\
\010\000\006\000\001\000\004\000\004\000\004\000\004\000\003\000\
\005\000\001\000\003\000\001\000\004\000\003\000\002\000\007\000\
\006\000\006\000\001\000\006\000\004\000\004\000\003\000\005\000\
\001\000\003\000\001\000\004\000\001\000\001\000\006\000\006\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\004\000\001\000\001\000\003\000\003\000\005\000\005\000\010\000\
\010\000\005\000\005\000\005\000\005\000\005\000\005\000\005\000\
\005\000\010\000\010\000\005\000\005\000\005\000\005\000\002\000\
\005\000\002\000\005\000\005\000\002\000\005\000\005\000\007\000\
\004\000\007\000\007\000\001\000\003\000\006\000\009\000\005\000\
\003\000\007\000\004\000\004\000\004\000\007\000\007\000\010\000\
\010\000\006\000\009\000\009\000\001\000\001\000\007\000\007\000\
\007\000\001\000\005\000\003\000\007\000\007\000\007\000\005\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\002\000"

let yydefred = "\000\000\
\240\000\000\000\034\001\000\000\032\001\000\000\000\000\004\000\
\005\000\000\000\244\000\000\000\000\000\032\001\101\000\003\000\
\000\000\016\001\000\000\000\000\010\000\245\000\000\000\013\001\
\032\001\032\001\000\000\000\000\001\000\000\000\243\000\246\000\
\000\000\255\000\006\001\000\000\244\000\000\000\000\000\000\000\
\000\000\244\000\244\000\017\001\111\000\112\000\032\001\032\001\
\032\001\000\000\105\000\244\000\000\000\015\001\000\000\000\000\
\000\000\000\000\032\001\000\000\000\000\113\000\114\000\115\000\
\116\000\000\000\000\000\000\000\000\000\108\000\109\000\110\000\
\103\000\000\000\007\000\000\000\082\000\000\000\000\000\243\000\
\254\000\000\000\253\000\011\000\028\001\000\000\000\000\032\001\
\000\000\017\001\000\000\000\000\000\000\239\000\000\000\000\000\
\000\000\000\000\017\001\000\000\244\000\000\000\131\000\000\000\
\118\000\204\000\248\000\000\000\000\000\000\000\247\000\097\000\
\000\000\241\000\242\000\087\000\240\000\029\001\016\000\018\000\
\000\000\249\000\000\000\000\000\252\000\000\000\000\000\000\000\
\013\001\000\000\017\001\253\000\000\000\000\000\119\000\120\000\
\121\000\122\000\000\000\013\001\000\000\000\000\024\001\000\000\
\000\000\000\000\000\000\000\000\000\000\099\000\253\000\000\000\
\003\001\050\000\000\000\000\000\000\000\081\000\000\000\008\000\
\000\000\243\000\031\001\000\000\009\000\243\000\000\000\032\001\
\000\000\127\000\253\000\000\000\000\000\000\000\000\000\000\000\
\017\001\000\000\000\000\000\000\250\000\205\000\017\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\117\000\032\001\
\000\000\000\000\000\000\244\000\244\000\017\001\000\000\244\000\
\000\000\000\000\000\000\241\000\000\000\240\000\251\000\253\000\
\000\000\000\000\243\000\021\000\023\000\000\000\243\000\014\000\
\157\000\000\000\161\000\163\000\164\000\244\000\168\000\166\000\
\165\000\167\000\162\000\000\000\000\000\244\000\135\000\000\000\
\140\000\032\001\032\001\000\000\000\000\000\000\018\001\000\000\
\130\000\013\001\013\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\152\000\242\000\000\000\000\000\000\000\
\000\000\000\000\000\000\013\001\000\000\024\001\018\001\024\001\
\049\000\055\000\056\000\000\000\005\001\006\000\000\000\000\000\
\000\000\242\000\084\000\000\000\242\000\085\000\020\000\032\001\
\000\001\137\000\027\001\000\000\000\000\000\000\000\000\000\000\
\250\000\000\000\000\000\000\000\143\000\106\000\032\001\128\000\
\018\001\017\001\000\000\253\000\253\000\199\000\126\000\247\000\
\000\000\098\000\017\001\209\000\017\001\017\001\017\001\000\000\
\000\000\250\000\250\000\000\000\017\001\000\000\013\001\000\000\
\052\000\000\000\000\000\086\000\000\000\000\000\000\000\000\000\
\024\000\026\000\030\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\139\000\000\000\107\000\
\013\001\013\001\235\000\236\000\253\000\000\000\000\000\000\000\
\000\000\013\001\013\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\198\000\000\000\000\000\
\007\001\244\000\243\000\000\000\250\000\036\000\038\000\253\000\
\000\000\253\000\000\000\000\000\252\000\000\000\001\001\253\000\
\253\000\000\000\141\000\172\000\173\000\247\000\169\000\000\000\
\193\000\253\000\000\000\203\000\000\000\022\001\200\000\253\000\
\253\000\000\000\000\000\208\000\247\000\247\000\018\001\018\001\
\000\000\000\000\000\000\000\000\253\000\000\000\000\000\000\000\
\090\000\000\000\093\000\032\001\000\000\012\001\244\000\029\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\129\000\000\000\000\000\000\000\018\001\018\001\000\000\000\000\
\013\001\013\001\000\000\000\000\000\000\244\000\244\000\017\001\
\000\000\004\001\004\001\008\001\059\000\008\001\068\000\000\000\
\000\000\000\000\000\000\000\000\091\000\094\000\028\000\000\000\
\000\000\155\000\150\000\000\000\000\000\000\000\000\000\007\001\
\025\001\159\000\160\000\146\000\000\000\145\000\202\000\000\000\
\000\000\017\001\244\000\226\000\207\000\215\000\214\000\000\000\
\000\000\022\001\022\001\196\000\195\000\210\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\039\000\243\000\000\000\242\000\088\000\253\000\
\000\000\019\001\000\000\032\000\042\000\000\000\000\000\000\000\
\244\000\147\000\144\000\000\000\000\000\000\000\000\000\253\000\
\253\000\000\000\000\000\000\000\000\000\017\001\017\001\000\000\
\253\000\253\000\000\000\019\001\020\001\021\001\033\001\033\001\
\007\001\007\001\019\001\020\001\021\001\018\001\041\000\000\000\
\095\000\000\000\154\000\000\000\000\000\013\001\000\000\000\000\
\244\000\244\000\017\001\000\000\044\000\008\001\011\001\015\000\
\045\000\000\000\000\000\017\001\017\001\000\000\017\001\000\000\
\000\000\000\000\000\000\017\001\244\000\220\000\233\000\219\000\
\234\000\253\000\013\001\000\000\013\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\253\000\156\000\000\000\034\000\
\253\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\013\001\013\001\000\000\000\000\216\000\
\217\000\000\000\000\000\000\000\000\000\000\000\000\000\253\000\
\253\000\060\000\253\000\253\000\000\000\000\000\253\000\253\000\
\179\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\244\000\053\000\002\001\075\000\054\000\058\000\066\000\
\067\000\008\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\017\001\000\000\017\001\017\001\000\000\
\019\001\020\001\021\001\007\001\251\000\149\000\000\000\253\000\
\253\000\227\000\000\000\017\001\228\000\017\001\000\000\000\000\
\017\001\071\000\000\000\000\000\000\000\000\000\018\001\018\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\096\000\035\000\013\001\013\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\013\001\
\013\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\063\000\072\000\017\001\012\001\000\000\000\000\007\001\
\037\000\000\000\000\000\000\000\000\000\000\000\000\000\148\000\
\225\000\224\000\223\000\253\000\253\000\232\000\000\000\000\000\
\000\000\000\000\000\000\000\000\013\001\000\000\000\000\013\001\
\074\000\000\000\018\001\018\001\013\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\253\000\019\001\078\000\
\253\000\000\000\000\000\250\000\048\000\231\000\230\000\229\000\
\176\000\187\000\177\000\186\000\000\000\000\000\000\000\000\000\
\000\000\000\000\080\000\009\001\076\000\079\000\047\000\000\000\
\253\000\000\000\077\000"

let yydgoto = "\002\000\
\003\000\004\000\006\000\014\000\112\000\007\000\008\000\009\000\
\010\000\017\000\032\000\018\000\076\000\110\000\082\000\033\000\
\056\000\011\000\113\000\058\000\083\000\244\000\030\000\084\000\
\085\000\124\000\019\000\057\000\081\000\121\000\163\000\214\000\
\025\001\077\001\127\001\170\001\217\001\007\002\056\002\119\000\
\120\000\161\000\212\000\086\000\073\001\074\001\075\001\124\001\
\168\001\169\001\213\001\044\002\201\000\068\000\044\001\117\001\
\118\001\043\001\119\001\066\001\005\002\155\001\143\002\057\002\
\105\002\015\001\140\000\141\000\153\000\204\000\077\000\205\000\
\012\001\013\001\245\001\085\002\139\002\144\002\142\002\196\001\
\247\001\197\001\198\001\199\001\059\001\140\002\255\000\202\000\
\150\000\078\000\114\000\115\000\159\000\019\001\022\001\116\000\
\156\000\255\001\151\000\015\000\027\000\028\000\036\000\076\001\
\172\000\045\000\046\000\104\000\105\000\093\001\144\000\167\000\
\231\000\164\000\232\000\233\000\011\002\211\001\149\000\212\001\
\078\001\033\001\083\002\203\000\084\002\184\000\106\000\178\001\
\229\001\072\002\070\002"

let yysindex = "\061\000\
\000\000\000\000\000\000\076\255\000\000\148\255\076\255\000\000\
\000\000\000\000\000\000\157\255\111\000\000\000\000\000\000\000\
\124\255\000\000\146\255\186\255\000\000\000\000\239\003\000\000\
\000\000\000\000\241\255\111\000\000\000\235\255\000\000\000\000\
\199\255\000\000\000\000\026\255\000\000\239\003\239\003\239\003\
\239\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\006\000\000\000\000\000\059\000\000\000\000\000\060\000\
\084\000\000\000\000\000\012\000\057\000\000\000\000\000\000\000\
\000\000\068\000\074\000\051\255\103\000\000\000\000\000\000\000\
\000\000\095\000\000\000\126\000\000\000\130\000\146\000\000\000\
\000\000\158\000\000\000\000\000\000\000\128\000\184\000\000\000\
\000\000\000\000\069\255\000\000\000\000\000\000\239\003\239\003\
\239\003\239\003\000\000\000\000\000\000\143\000\000\000\122\000\
\000\000\000\000\000\000\000\000\000\000\196\000\000\000\000\000\
\166\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\218\000\000\000\194\000\212\000\000\000\197\000\024\001\253\000\
\000\000\230\255\000\000\000\000\006\001\032\001\000\000\000\000\
\000\000\000\000\051\255\000\000\021\001\033\001\000\000\163\001\
\051\255\051\255\051\255\049\001\074\001\000\000\000\000\217\000\
\000\000\000\000\119\001\107\001\130\000\000\000\104\255\000\000\
\088\001\000\000\000\000\091\001\000\000\000\000\010\004\000\000\
\083\001\000\000\000\000\230\255\000\000\142\255\230\255\105\001\
\000\000\000\000\143\000\122\000\000\000\000\000\000\000\230\255\
\230\255\230\255\230\255\029\255\122\000\130\001\000\000\000\000\
\109\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\110\001\117\001\118\001\000\000\116\255\000\000\000\000\000\000\
\130\000\130\000\000\000\000\000\000\000\147\001\000\000\000\000\
\000\000\139\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\010\004\029\002\000\000\000\000\118\255\
\000\000\000\000\000\000\141\001\052\000\145\001\000\000\143\000\
\000\000\000\000\000\000\161\001\168\001\134\001\230\255\143\000\
\143\000\143\000\143\000\000\000\000\000\146\001\199\001\178\001\
\188\001\194\001\217\000\000\000\201\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\183\001\205\001\
\213\001\000\000\000\000\221\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\234\001\243\255\215\001\231\001\243\255\
\000\000\245\001\010\004\010\004\000\000\000\000\000\000\000\000\
\000\000\000\000\039\000\000\000\000\000\000\000\000\000\000\000\
\143\000\000\000\000\000\000\000\000\000\000\000\000\000\110\001\
\118\001\000\000\000\000\217\000\000\000\217\000\000\000\217\000\
\000\000\239\001\021\255\000\000\130\000\021\002\130\000\246\001\
\000\000\000\000\000\000\001\002\044\002\014\000\010\004\006\002\
\048\000\048\000\008\002\022\002\010\004\000\000\019\002\000\000\
\000\000\000\000\000\000\000\000\000\000\038\002\042\002\054\002\
\052\002\000\000\000\000\217\000\217\000\056\002\064\002\086\002\
\063\000\151\000\217\000\110\001\118\001\000\000\110\001\118\001\
\000\000\000\000\000\000\112\002\000\000\000\000\000\000\000\000\
\130\000\000\000\130\000\087\002\000\000\124\000\000\000\000\000\
\000\000\243\255\000\000\000\000\000\000\000\000\000\000\243\255\
\000\000\000\000\095\002\000\000\000\000\000\000\000\000\000\000\
\000\000\093\002\097\002\000\000\000\000\000\000\000\000\000\000\
\110\001\118\001\240\255\099\002\000\000\000\000\100\002\111\002\
\000\000\126\002\000\000\000\000\053\004\000\000\000\000\000\000\
\159\002\175\002\141\002\148\002\151\002\179\002\157\002\166\002\
\000\000\219\255\169\002\183\002\000\000\000\000\200\002\212\002\
\000\000\000\000\189\002\000\000\000\000\000\000\000\000\000\000\
\110\001\000\000\000\000\000\000\000\000\000\000\000\000\118\001\
\193\002\195\002\194\002\130\000\000\000\000\000\000\000\053\004\
\048\000\000\000\000\000\201\002\191\002\203\002\124\000\000\000\
\000\000\000\000\000\000\000\000\029\004\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\217\000\
\217\000\000\000\000\000\000\000\000\000\000\000\209\002\210\002\
\213\002\215\002\013\000\035\002\220\002\221\002\244\002\248\002\
\103\002\219\002\000\000\000\000\228\002\000\000\000\000\000\000\
\053\004\000\000\000\000\000\000\000\000\114\000\010\003\010\004\
\000\000\000\000\000\000\231\002\237\002\230\255\242\002\000\000\
\000\000\222\255\222\255\222\002\000\000\000\000\000\000\110\001\
\000\000\000\000\118\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\130\000\
\000\000\255\002\000\000\230\255\001\003\000\000\000\000\000\000\
\000\000\000\000\000\000\143\000\000\000\000\000\000\000\000\000\
\000\000\243\255\005\003\000\000\000\000\143\000\000\000\017\003\
\018\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\019\003\000\000\217\000\240\255\020\003\
\026\003\217\000\217\000\217\000\168\000\168\000\240\255\240\255\
\217\000\217\000\217\000\230\255\000\000\000\000\143\000\000\000\
\000\000\011\003\030\003\031\003\036\003\035\001\122\002\058\003\
\029\003\048\003\010\004\000\000\000\000\049\003\230\255\000\000\
\000\000\052\003\086\003\073\003\217\000\076\003\077\003\000\000\
\000\000\000\000\000\000\000\000\173\000\203\000\000\000\000\000\
\000\000\000\000\110\001\118\001\110\001\118\001\110\001\118\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\110\001\118\001\110\001\118\001\110\001\118\001\
\143\000\080\003\083\003\000\000\000\000\000\000\000\000\143\000\
\000\000\000\000\000\000\000\000\000\000\000\000\243\255\000\000\
\000\000\000\000\143\000\000\000\000\000\000\000\110\001\118\001\
\000\000\000\000\084\003\090\003\091\003\092\003\000\000\000\000\
\099\003\104\003\108\003\102\003\110\003\137\003\140\003\116\003\
\000\000\000\000\000\000\000\000\217\000\114\000\230\255\230\255\
\230\255\114\000\119\003\117\003\122\003\129\003\130\003\000\000\
\000\000\135\003\217\000\000\000\000\000\000\000\000\000\217\000\
\217\000\000\000\000\000\000\000\000\000\000\000\168\000\000\000\
\000\000\240\000\251\000\143\000\143\000\143\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\110\001\118\001\
\110\001\118\001\110\001\118\001\000\000\128\003\142\003\000\000\
\000\000\240\255\000\000\000\000\000\000\138\003\143\003\145\003\
\146\003\151\003\152\003\154\003\156\003\000\000\000\000\000\000\
\000\000\230\255\230\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\162\003\083\000\163\003\143\000\
\143\000\164\003\000\000\000\000\000\000\000\000\000\000\168\003\
\000\000\169\003\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\211\003\105\255\000\000\
\000\000\031\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\207\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\249\255\000\000\
\060\001\049\255\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\044\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\119\000\000\000\000\000\094\003\107\002\000\000\000\000\000\000\
\000\000\000\000\000\000\038\001\000\000\161\002\000\000\109\001\
\000\000\000\000\000\000\064\000\189\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\231\000\000\000\000\000\172\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\082\002\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\044\255\000\000\047\255\000\000\
\136\001\000\000\000\000\121\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\112\003\000\000\000\000\000\000\
\000\000\119\000\202\000\109\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\154\255\175\003\222\000\000\000\000\000\
\000\000\147\002\165\002\000\000\000\000\000\000\154\000\000\000\
\070\001\085\255\192\003\000\000\000\000\000\000\000\000\000\000\
\044\255\044\255\000\000\000\000\000\000\207\000\000\000\000\000\
\000\000\157\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\245\002\
\000\000\000\000\000\000\000\000\193\255\000\000\000\000\109\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\171\003\
\026\000\187\000\090\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\198\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\109\001\179\003\182\003\188\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\109\001\000\000\000\000\000\000\000\000\000\000\000\000\109\001\
\109\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\237\003\000\000\044\255\056\255\044\255\071\255\
\000\000\000\000\000\000\000\000\203\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\071\002\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\125\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\193\255\047\000\000\000\223\002\223\000\000\000\025\003\050\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\044\255\000\000\044\255\041\002\000\000\000\000\000\000\000\000\
\000\000\109\001\000\000\000\000\000\000\000\000\000\000\109\001\
\000\000\000\000\000\000\000\000\231\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\109\001\109\001\000\000\000\000\000\000\063\003\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\092\000\089\255\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\182\002\240\002\
\000\000\000\000\000\000\066\002\039\001\000\000\000\000\000\000\
\161\002\000\000\000\000\000\000\000\000\000\000\000\000\161\002\
\237\003\000\000\000\000\044\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\054\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\094\003\
\112\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\018\001\201\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\119\000\000\000\000\000\000\000\052\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\232\000\134\000\000\000\000\000\202\000\
\000\000\000\000\202\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\044\255\
\000\000\000\000\000\000\000\000\000\000\000\000\118\002\039\001\
\000\000\000\000\000\000\161\002\000\000\000\000\000\000\000\000\
\000\000\109\001\000\000\000\000\000\000\109\001\000\000\000\000\
\000\000\147\002\165\002\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\197\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\136\255\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\150\000\007\001\185\001\071\001\061\002\210\001\
\037\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\219\001\228\001\000\002\026\002\062\002\070\002\
\109\001\000\000\000\000\000\000\119\000\000\000\000\000\202\000\
\000\000\000\000\000\000\000\000\000\000\000\000\109\001\000\000\
\000\000\000\000\109\001\000\000\000\000\000\000\109\001\109\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\027\002\202\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\191\003\137\001\216\003\000\003\000\000\
\000\000\000\000\000\000\000\000\000\000\134\000\000\000\000\000\
\000\000\000\000\000\000\142\001\190\002\032\003\038\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\109\001\109\001\
\109\001\109\001\109\001\109\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\109\001\
\109\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\184\255\239\004\000\000\237\004\000\000\000\000\000\000\
\000\000\000\000\000\000\222\004\000\000\000\000\231\255\000\000\
\000\000\000\000\155\002\000\000\000\000\190\255\010\000\089\004\
\205\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\045\004\000\000\000\000\143\255\000\000\095\003\000\000\000\000\
\045\003\000\000\047\002\252\253\042\000\077\000\185\000\000\000\
\061\003\254\254\174\254\111\003\000\000\049\254\135\254\000\000\
\000\000\106\002\058\255\094\255\134\002\009\004\210\255\000\000\
\000\000\000\000\085\003\249\002\207\253\117\254\000\000\067\254\
\070\254\043\254\205\002\043\003\171\254\000\000\222\253\163\254\
\195\254\000\000\102\255\073\255\007\255\170\003\166\003\000\000\
\013\255\000\000\000\000\000\000\006\005\000\000\000\000\229\255\
\232\255\171\002\038\000\195\003\214\004\000\000\104\254\181\003\
\016\004\000\000\038\255\134\254\000\000\092\254\000\000\000\000\
\000\000\191\000\238\253\193\000\005\254\023\000\118\254\085\000\
\033\003\000\000\034\003"

let yytablesize = 1379
let yytable = "\047\000\
\004\001\110\001\208\000\050\001\063\001\053\000\146\001\147\001\
\006\002\029\001\032\001\248\001\144\001\145\001\012\000\195\001\
\123\000\090\002\246\000\070\000\071\000\072\000\128\000\082\002\
\070\001\018\001\021\001\072\001\118\000\025\002\089\002\115\002\
\157\001\194\001\048\000\049\000\141\002\148\000\089\001\228\001\
\244\001\091\002\210\001\000\002\160\000\032\001\145\000\249\001\
\213\000\243\000\147\000\092\000\093\000\094\000\083\000\009\001\
\069\000\069\000\069\000\114\001\096\001\001\000\154\000\089\000\
\115\001\176\000\046\000\158\000\087\000\092\000\093\000\094\000\
\054\002\087\001\095\000\096\000\097\000\098\000\092\000\005\000\
\244\000\087\002\088\002\152\000\193\000\210\001\059\000\244\000\
\060\000\042\000\043\000\083\000\043\002\012\000\099\000\043\000\
\100\000\127\000\010\002\236\001\089\000\026\001\188\002\043\000\
\236\000\103\000\002\000\042\000\043\000\102\000\046\000\128\000\
\131\000\245\000\100\000\092\000\130\001\010\001\011\001\101\000\
\002\000\209\000\136\001\104\002\237\001\083\001\084\001\244\001\
\103\000\197\000\249\001\197\000\102\000\014\001\210\001\228\001\
\228\001\101\000\016\002\017\002\053\002\016\001\057\000\200\002\
\025\002\127\002\174\001\043\000\185\001\186\001\057\000\103\001\
\104\001\210\000\146\002\103\002\199\002\009\001\021\000\118\000\
\035\001\183\001\184\001\013\000\252\000\129\000\130\000\201\002\
\036\001\039\002\120\001\174\000\122\001\249\002\123\000\139\000\
\103\000\234\000\232\001\233\001\179\000\031\000\103\000\103\000\
\103\000\037\001\102\000\102\000\102\000\239\000\002\001\002\001\
\143\000\018\001\057\000\021\001\241\000\034\000\123\000\003\001\
\003\001\069\000\033\000\033\000\145\002\051\000\038\001\175\000\
\030\000\030\000\159\001\033\000\202\002\237\000\033\000\191\002\
\240\000\030\000\080\001\224\001\225\001\094\000\066\002\067\002\
\094\000\248\000\249\000\250\000\251\000\035\000\092\000\173\000\
\094\000\094\001\095\001\060\001\052\000\192\000\097\001\192\000\
\188\001\189\001\094\000\069\000\039\001\121\002\102\001\124\002\
\050\000\032\003\014\001\196\000\197\000\242\000\243\000\033\000\
\241\000\055\000\022\003\247\000\041\002\030\000\226\001\103\002\
\127\002\068\002\014\001\088\001\054\002\194\000\195\000\094\000\
\250\002\131\000\003\001\100\000\254\001\073\000\190\001\191\001\
\196\000\197\000\139\001\192\001\062\001\199\000\064\001\227\001\
\049\001\069\000\069\002\092\002\014\001\036\001\152\000\091\001\
\092\001\116\001\101\000\132\000\056\001\058\002\132\000\132\000\
\069\000\030\001\031\001\190\001\200\000\160\001\037\001\162\001\
\192\001\171\000\199\000\075\000\146\002\171\001\172\001\173\001\
\013\001\013\001\013\001\079\000\181\000\175\001\132\000\176\001\
\088\000\060\001\060\001\013\001\013\001\179\001\180\001\128\001\
\129\001\200\000\246\000\194\000\195\000\094\000\097\001\187\001\
\026\001\116\001\202\001\194\000\080\000\194\000\196\000\197\000\
\028\003\031\000\031\000\041\001\089\000\105\001\143\000\108\001\
\107\000\111\001\031\000\013\001\100\000\013\001\151\001\090\000\
\022\000\006\001\047\002\048\002\094\000\091\000\090\001\017\001\
\017\001\017\001\236\002\237\002\166\001\167\001\198\000\098\001\
\199\000\099\001\100\001\101\001\013\001\023\000\017\001\017\001\
\017\001\107\001\108\000\145\000\109\000\093\002\146\000\147\000\
\167\002\017\001\017\001\111\000\153\001\117\000\031\000\200\000\
\049\002\050\002\023\001\023\001\023\001\051\002\122\000\100\000\
\060\001\152\000\017\001\253\000\017\001\023\001\023\001\174\000\
\137\002\138\002\024\000\045\001\025\000\069\000\026\000\116\001\
\125\000\017\001\253\000\017\001\216\002\217\002\101\000\006\003\
\029\003\126\000\009\003\017\001\058\001\042\002\174\000\174\000\
\045\002\143\000\174\000\057\001\193\001\023\001\152\001\023\001\
\250\000\008\001\017\001\155\000\133\000\064\002\065\002\133\000\
\133\000\157\000\076\002\025\000\025\000\025\000\080\002\081\002\
\102\001\194\000\195\000\094\000\183\002\025\000\023\001\006\001\
\212\000\212\000\116\001\162\000\196\000\197\000\212\000\133\000\
\017\001\017\001\017\001\022\000\022\000\022\000\165\000\124\000\
\212\000\022\000\124\000\017\001\017\001\022\000\253\000\106\002\
\010\003\011\003\184\002\110\002\106\001\008\001\109\001\010\001\
\112\001\010\001\010\001\166\000\198\000\168\000\199\000\119\002\
\212\000\025\000\124\000\212\000\243\001\212\000\212\000\132\001\
\133\001\137\001\138\001\017\001\212\000\017\001\212\000\212\000\
\181\000\169\000\154\002\138\001\024\002\200\000\155\002\251\002\
\253\002\022\000\006\001\092\000\173\000\094\000\023\001\023\001\
\023\001\170\000\252\002\154\001\017\001\008\001\014\002\052\002\
\181\000\177\000\060\001\181\000\060\001\179\002\180\002\062\002\
\181\002\182\002\057\000\064\000\185\002\186\002\018\002\019\002\
\017\000\017\000\017\000\182\000\254\002\017\000\017\000\221\000\
\221\000\049\002\017\000\178\000\183\000\221\000\051\002\046\002\
\100\000\023\001\244\000\023\001\250\000\095\002\192\002\221\000\
\184\000\238\000\076\002\200\001\238\000\191\000\238\000\238\000\
\075\002\077\002\078\002\079\002\204\002\205\002\206\002\101\000\
\207\002\026\003\023\001\134\000\110\002\210\002\134\000\134\000\
\184\000\137\001\221\000\184\000\221\000\221\000\017\000\125\002\
\193\001\192\000\206\000\131\002\133\002\135\002\207\000\102\002\
\193\001\193\001\147\002\149\002\151\002\153\002\134\000\211\000\
\108\002\109\002\215\000\111\002\019\000\019\000\019\000\160\002\
\117\002\019\000\019\000\235\000\174\000\241\000\019\000\147\000\
\171\002\253\000\070\000\247\002\174\000\024\001\175\002\174\000\
\006\001\158\000\158\000\158\000\007\001\020\000\158\000\158\000\
\008\001\255\002\000\003\158\000\207\002\001\003\002\003\003\003\
\004\003\005\003\070\000\027\002\048\001\070\000\027\001\060\001\
\060\001\040\001\174\000\215\000\042\001\051\001\215\000\061\000\
\215\000\215\000\019\000\021\003\066\000\067\000\023\003\158\000\
\174\000\158\000\175\000\158\000\158\000\046\001\074\000\158\000\
\062\000\063\000\064\000\065\000\047\001\002\003\004\003\158\000\
\185\000\052\001\186\000\187\000\152\000\053\001\034\003\152\000\
\158\000\175\000\175\000\189\000\067\001\175\000\097\002\054\001\
\195\002\196\002\197\002\198\002\180\000\055\001\226\002\052\002\
\228\002\229\002\230\002\052\002\061\001\182\000\133\000\134\000\
\208\002\068\001\209\002\189\000\239\002\211\002\189\000\142\000\
\069\001\241\002\243\002\120\002\180\000\123\002\081\001\180\000\
\071\001\135\000\136\000\137\000\138\000\182\000\126\002\200\001\
\182\000\183\000\132\002\134\002\136\002\079\001\082\001\200\001\
\200\001\148\002\150\002\152\002\073\000\073\000\030\001\031\001\
\085\001\113\001\073\000\193\001\168\002\169\002\121\001\123\001\
\245\002\183\000\248\002\185\000\183\000\027\000\027\000\027\000\
\126\001\125\001\131\001\024\003\025\003\176\002\134\001\027\000\
\217\000\218\000\219\000\220\000\221\000\222\000\223\000\224\000\
\225\000\226\000\227\000\185\000\135\001\036\001\185\000\238\000\
\228\000\142\001\229\000\142\000\142\000\142\000\178\000\188\000\
\142\000\142\000\140\001\151\000\009\001\142\000\141\001\190\000\
\028\002\151\000\029\002\030\002\254\000\000\001\001\001\002\001\
\143\001\230\000\005\001\027\000\148\001\178\000\178\000\188\000\
\151\000\178\000\188\000\017\001\020\001\244\000\149\001\190\000\
\158\001\142\000\190\000\142\000\237\000\142\000\142\000\237\000\
\028\001\237\000\237\000\120\002\123\002\136\000\136\000\136\000\
\034\001\142\000\151\000\136\000\150\001\227\002\164\001\136\000\
\168\002\169\002\142\000\177\001\181\001\151\000\201\001\151\000\
\182\001\151\000\204\001\240\002\237\000\237\000\244\000\238\000\
\242\002\244\002\237\000\205\001\035\002\238\000\036\002\037\002\
\238\000\244\000\238\000\238\000\237\000\009\001\238\000\238\000\
\237\000\136\000\206\001\237\000\238\000\237\000\237\000\161\002\
\215\001\162\002\163\002\136\000\216\001\012\003\238\000\206\000\
\206\000\218\001\200\001\237\000\237\000\206\000\244\000\237\000\
\219\001\237\000\237\000\220\001\175\000\237\000\221\001\206\000\
\237\000\222\001\237\000\237\000\175\000\238\000\238\000\175\000\
\244\000\238\000\223\001\238\000\238\000\230\001\010\001\238\000\
\010\001\010\001\238\000\234\001\238\000\238\000\206\000\206\000\
\201\000\201\000\206\000\231\001\206\000\206\000\201\000\235\001\
\206\000\238\001\175\000\206\000\115\001\206\000\206\000\251\001\
\201\000\218\000\218\000\001\002\252\001\002\002\003\002\218\000\
\175\000\138\000\138\000\138\000\020\002\021\002\138\000\138\000\
\022\002\218\000\023\002\138\000\031\002\033\002\032\002\201\000\
\201\000\034\002\038\002\201\000\156\001\201\000\201\000\040\002\
\055\002\069\000\060\002\017\001\201\000\020\001\201\000\201\000\
\061\002\218\000\211\000\211\000\218\000\063\002\218\000\218\000\
\211\000\138\000\218\000\074\002\138\000\218\000\178\000\218\000\
\218\000\069\000\211\000\094\002\069\000\096\002\178\000\138\000\
\107\002\178\000\214\000\213\000\213\000\214\000\156\002\214\000\
\214\000\213\000\153\000\153\000\153\000\112\002\113\002\122\002\
\129\002\214\001\211\000\213\000\153\000\211\000\130\002\211\000\
\211\000\157\002\158\002\164\002\178\000\180\000\211\000\159\002\
\211\000\211\000\165\002\188\000\189\000\190\000\239\001\240\001\
\241\001\242\001\178\000\213\000\166\002\170\002\213\000\172\002\
\213\000\213\000\153\000\237\000\237\000\153\000\253\001\213\000\
\173\002\213\000\213\000\040\000\237\000\040\000\040\000\237\000\
\153\000\005\001\237\000\237\000\174\002\238\000\238\000\177\002\
\221\002\178\002\012\002\013\002\193\002\015\002\238\000\194\002\
\212\002\238\000\206\000\206\000\238\000\238\000\213\002\214\002\
\215\002\244\000\237\000\206\000\237\000\237\000\206\000\218\002\
\237\000\206\000\206\000\237\000\219\002\237\000\237\000\220\002\
\237\000\222\002\223\002\244\000\238\000\224\002\238\000\238\000\
\225\002\232\002\238\000\059\002\231\002\238\000\233\002\238\000\
\238\000\206\000\238\000\206\000\206\000\234\002\235\002\206\000\
\201\000\201\000\206\000\238\002\206\000\206\000\007\003\206\000\
\013\003\201\000\008\003\014\003\201\000\015\003\016\003\201\000\
\201\000\222\000\222\000\017\003\018\003\062\000\019\003\222\000\
\020\003\098\002\099\002\100\002\101\002\062\000\027\003\030\003\
\062\000\222\000\031\003\033\003\102\000\035\003\104\000\201\000\
\013\000\201\000\201\000\125\000\114\002\116\002\061\000\118\002\
\201\000\170\000\201\000\201\000\171\000\201\000\061\000\062\000\
\062\000\061\000\250\000\062\000\222\000\243\000\222\000\222\000\
\037\000\203\000\065\000\064\000\203\000\016\000\203\000\203\000\
\128\000\062\000\029\000\128\000\128\000\054\000\216\000\023\001\
\061\000\061\000\207\001\004\002\061\000\250\001\038\000\039\000\
\040\000\041\000\202\000\246\002\203\001\202\000\203\002\202\000\
\202\000\190\002\061\000\128\000\065\001\042\000\043\000\246\001\
\086\002\202\000\044\000\128\002\202\000\026\002\202\000\202\000\
\163\001\051\000\161\001\187\002\189\002\217\000\218\000\219\000\
\220\000\221\000\222\000\223\000\224\000\225\000\226\000\227\000\
\132\000\165\001\086\001\071\002\073\002\228\000\000\000\229\000\
\217\000\218\000\219\000\220\000\221\000\000\000\223\000\224\000\
\225\000\226\000\227\000\000\000\000\000\000\000\000\000\000\000\
\008\002\000\000\209\001\000\000\000\000\000\000\230\000\000\000\
\217\000\218\000\219\000\220\000\221\000\000\000\223\000\224\000\
\225\000\226\000\227\000\000\000\000\000\000\000\000\000\000\000\
\208\001\009\002\209\001"

let yycheck = "\024\000\
\199\000\063\001\157\000\253\000\007\001\031\000\100\001\101\001\
\216\001\228\000\229\000\198\001\098\001\099\001\005\000\155\001\
\083\000\036\002\181\000\047\000\048\000\049\000\089\000\028\002\
\018\001\209\000\210\000\021\001\080\000\243\001\035\002\066\002\
\115\001\155\001\025\000\026\000\086\002\104\000\041\001\178\001\
\193\001\037\002\165\001\208\001\117\000\002\001\018\001\200\001\
\162\000\001\001\022\001\001\001\002\001\003\001\008\001\019\001\
\047\000\048\000\049\000\039\001\048\001\001\000\109\000\008\001\
\044\001\132\000\015\001\114\000\059\000\001\001\002\001\003\001\
\006\002\036\001\024\001\025\001\026\001\027\001\008\001\004\001\
\044\001\033\002\034\002\108\000\151\000\208\001\061\001\044\001\
\063\001\039\001\040\001\045\001\001\002\045\001\044\001\007\001\
\046\001\088\000\221\001\185\001\045\001\215\000\137\002\015\001\
\171\000\068\000\002\001\039\001\040\001\068\000\059\001\178\000\
\044\001\180\000\046\001\045\001\079\001\002\001\003\001\069\001\
\016\001\018\001\085\001\054\002\186\001\032\001\033\001\024\002\
\091\000\045\001\027\002\047\001\091\000\206\000\001\002\018\002\
\019\002\069\001\232\001\233\001\006\002\208\000\007\001\162\002\
\102\002\079\002\134\001\059\001\151\001\152\001\015\001\058\001\
\059\001\050\001\088\002\052\002\161\002\204\000\002\001\211\000\
\043\001\149\001\150\001\016\001\192\000\089\000\090\000\163\002\
\051\001\252\001\069\001\130\000\071\001\223\002\021\001\099\000\
\139\000\168\000\181\001\182\001\139\000\058\001\145\000\146\000\
\147\000\068\001\145\000\146\000\147\000\048\001\002\001\003\001\
\051\001\121\001\059\001\123\001\008\001\052\001\045\001\002\001\
\003\001\192\000\006\001\007\001\088\002\008\001\234\000\131\000\
\006\001\007\001\117\001\015\001\164\002\172\000\018\001\146\002\
\175\000\015\001\029\001\001\001\002\001\003\001\001\001\002\001\
\003\001\184\000\185\000\186\000\187\000\044\001\001\001\002\001\
\003\001\044\001\045\001\004\001\002\001\045\001\049\001\047\001\
\001\001\002\001\003\001\234\000\235\000\075\002\057\001\077\002\
\008\001\028\003\002\001\012\001\013\001\177\000\178\000\059\001\
\008\001\059\001\007\003\183\000\254\001\059\001\044\001\160\002\
\198\002\044\001\018\001\039\001\202\002\001\001\002\001\003\001\
\224\002\044\001\198\000\046\001\204\001\016\001\039\001\040\001\
\012\001\013\001\093\001\044\001\006\001\046\001\008\001\069\001\
\247\000\024\001\069\001\038\002\044\001\051\001\063\001\001\001\
\002\001\067\001\069\001\018\001\003\001\008\002\021\001\022\001\
\039\001\002\001\003\001\039\001\069\001\120\001\068\001\122\001\
\044\001\129\000\046\001\001\001\250\002\128\001\129\001\130\001\
\001\001\002\001\003\001\008\001\140\000\136\001\045\001\138\001\
\061\001\098\001\099\001\012\001\013\001\144\001\145\001\066\001\
\067\001\069\001\052\001\001\001\002\001\003\001\153\001\154\001\
\058\001\115\001\157\001\045\001\009\001\047\001\012\001\013\001\
\014\001\006\001\007\001\048\001\044\001\060\001\051\001\062\001\
\002\001\064\001\015\001\044\001\045\001\046\001\048\001\044\001\
\002\001\051\001\001\001\002\001\003\001\044\001\042\001\001\001\
\002\001\003\001\208\002\209\002\001\001\002\001\044\001\051\001\
\046\001\053\001\054\001\055\001\069\001\023\001\001\001\002\001\
\003\001\061\001\044\001\018\001\015\001\040\002\021\001\022\001\
\107\002\012\001\013\001\018\001\107\001\004\001\059\001\069\001\
\039\001\040\001\001\001\002\001\003\001\044\001\001\001\046\001\
\185\001\186\001\044\001\045\001\046\001\012\001\013\001\018\001\
\001\001\002\001\060\001\243\000\062\001\164\001\064\001\201\001\
\049\001\044\001\045\001\046\001\183\002\184\002\069\001\245\002\
\022\003\002\001\248\002\069\001\004\001\000\002\041\001\042\001\
\003\002\051\001\045\001\003\001\155\001\044\001\048\001\046\001\
\047\001\051\001\069\001\008\001\018\001\016\002\017\002\021\001\
\022\001\044\001\021\002\005\001\006\001\007\001\025\002\026\002\
\027\002\001\001\002\001\003\001\048\001\015\001\069\001\051\001\
\002\001\003\001\252\001\010\001\012\001\013\001\008\001\045\001\
\001\001\002\001\003\001\005\001\006\001\007\001\045\001\018\001\
\018\001\011\001\021\001\012\001\013\001\015\001\045\001\058\002\
\251\002\252\002\048\001\062\002\060\001\051\001\062\001\054\001\
\064\001\056\001\057\001\048\001\044\001\065\001\046\001\074\002\
\042\001\059\001\045\001\045\001\192\001\047\001\048\001\081\001\
\082\001\089\001\090\001\044\001\054\001\046\001\056\001\057\001\
\018\001\002\001\093\002\099\001\243\001\069\001\097\002\048\001\
\231\002\059\001\051\001\001\001\002\001\003\001\001\001\002\001\
\003\001\045\001\048\001\107\001\069\001\051\001\226\001\006\002\
\042\001\044\001\075\002\045\001\077\002\120\002\121\002\014\002\
\123\002\124\002\041\001\042\001\127\002\128\002\234\001\235\001\
\005\001\006\001\007\001\047\001\231\002\010\001\011\001\002\001\
\003\001\039\001\015\001\044\001\044\001\008\001\044\001\003\002\
\046\001\044\001\044\001\046\001\047\001\044\002\153\002\018\001\
\018\001\051\001\157\002\155\001\054\001\045\001\056\001\057\001\
\020\002\021\002\022\002\023\002\167\002\168\002\169\002\069\001\
\171\002\012\003\069\001\018\001\175\002\176\002\021\001\022\001\
\042\001\185\001\045\001\045\001\047\001\048\001\059\001\078\002\
\079\002\048\001\004\001\082\002\083\002\084\002\020\001\051\002\
\087\002\088\002\089\002\090\002\091\002\092\002\045\001\048\001\
\060\002\061\002\048\001\063\002\005\001\006\001\007\001\102\002\
\068\002\010\001\011\001\065\001\007\001\045\001\015\001\022\001\
\111\002\045\001\018\001\222\002\015\001\011\001\117\002\018\001\
\051\001\005\001\006\001\007\001\048\001\011\000\010\001\011\001\
\051\001\236\002\237\002\015\001\239\002\240\002\241\002\242\002\
\243\002\244\002\042\001\243\001\047\001\045\001\044\001\208\002\
\209\002\045\001\045\001\051\001\044\001\044\001\054\001\037\000\
\056\001\057\001\059\001\006\003\042\000\043\000\009\003\043\001\
\059\001\045\001\018\001\047\001\048\001\045\001\052\000\051\001\
\038\000\039\000\040\000\041\000\045\001\024\003\025\003\059\001\
\054\001\019\001\056\001\057\001\245\002\044\001\033\003\248\002\
\068\001\041\001\042\001\018\001\046\001\045\001\046\002\044\001\
\156\002\157\002\158\002\159\002\018\001\044\001\197\002\198\002\
\199\002\200\002\201\002\202\002\044\001\018\001\092\000\093\000\
\172\002\045\001\174\002\042\001\211\002\177\002\045\001\101\000\
\044\001\216\002\217\002\075\002\042\001\077\002\048\001\045\001\
\044\001\095\000\096\000\097\000\098\000\042\001\078\002\079\002\
\045\001\018\001\082\002\083\002\084\002\044\001\048\001\087\002\
\088\002\089\002\090\002\091\002\002\001\003\001\002\001\003\001\
\044\001\051\001\008\001\250\002\108\002\109\002\018\001\050\001\
\220\002\042\001\222\002\018\001\045\001\005\001\006\001\007\001\
\005\001\049\001\045\001\010\003\011\003\117\002\047\001\015\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\042\001\047\001\051\001\045\001\173\000\
\044\001\020\001\046\001\005\001\006\001\007\001\018\001\018\001\
\010\001\011\001\045\001\002\001\019\001\015\001\045\001\018\001\
\054\001\008\001\056\001\057\001\194\000\195\000\196\000\197\000\
\045\001\069\001\200\000\059\001\045\001\041\001\042\001\042\001\
\023\001\045\001\045\001\209\000\210\000\044\001\047\001\042\001\
\001\001\043\001\045\001\045\001\051\001\047\001\048\001\054\001\
\222\000\056\001\057\001\195\002\196\002\005\001\006\001\007\001\
\230\000\059\001\049\001\011\001\047\001\197\002\048\001\015\001\
\208\002\209\002\068\001\045\001\048\001\060\001\044\001\062\001\
\048\001\064\001\047\001\211\002\002\001\003\001\044\001\045\001\
\216\002\217\002\008\001\045\001\054\001\051\001\056\001\057\001\
\054\001\044\001\056\001\057\001\018\001\019\001\002\001\003\001\
\051\001\049\001\045\001\054\001\008\001\056\001\057\001\054\001\
\018\001\056\001\057\001\059\001\006\001\253\002\018\001\002\001\
\003\001\045\001\250\002\041\001\042\001\008\001\044\001\045\001\
\045\001\047\001\048\001\045\001\007\001\051\001\020\001\018\001\
\054\001\045\001\056\001\057\001\015\001\041\001\042\001\018\001\
\044\001\045\001\045\001\047\001\048\001\045\001\054\001\051\001\
\056\001\057\001\054\001\020\001\056\001\057\001\041\001\042\001\
\002\001\003\001\045\001\045\001\047\001\048\001\008\001\020\001\
\051\001\045\001\045\001\054\001\044\001\056\001\057\001\045\001\
\018\001\002\001\003\001\043\001\051\001\055\001\044\001\008\001\
\059\001\005\001\006\001\007\001\044\001\044\001\010\001\011\001\
\044\001\018\001\044\001\015\001\041\001\018\001\042\001\041\001\
\042\001\018\001\048\001\045\001\114\001\047\001\048\001\044\001\
\007\001\018\001\044\001\121\001\054\001\123\001\056\001\057\001\
\044\001\042\001\002\001\003\001\045\001\044\001\047\001\048\001\
\008\001\045\001\051\001\070\001\048\001\054\001\007\001\056\001\
\057\001\042\001\018\001\045\001\045\001\045\001\015\001\059\001\
\044\001\018\001\051\001\002\001\003\001\054\001\044\001\056\001\
\057\001\008\001\005\001\006\001\007\001\045\001\045\001\045\001\
\045\001\167\001\042\001\018\001\015\001\045\001\045\001\047\001\
\048\001\044\001\044\001\018\001\045\001\139\000\054\001\044\001\
\056\001\057\001\054\001\145\000\146\000\147\000\188\001\189\001\
\190\001\191\001\059\001\042\001\045\001\045\001\045\001\044\001\
\047\001\048\001\045\001\006\001\007\001\048\001\204\001\054\001\
\019\001\056\001\057\001\045\001\015\001\047\001\048\001\018\001\
\059\001\051\001\021\001\022\001\044\001\006\001\007\001\044\001\
\019\001\045\001\224\001\225\001\045\001\227\001\015\001\045\001\
\045\001\018\001\006\001\007\001\021\001\022\001\045\001\045\001\
\045\001\044\001\045\001\015\001\047\001\048\001\018\001\045\001\
\051\001\021\001\022\001\054\001\045\001\056\001\057\001\044\001\
\059\001\044\001\018\001\044\001\045\001\018\001\047\001\048\001\
\045\001\045\001\051\001\009\002\046\001\054\001\045\001\056\001\
\057\001\045\001\059\001\047\001\048\001\045\001\045\001\051\001\
\006\001\007\001\054\001\045\001\056\001\057\001\055\001\059\001\
\047\001\015\001\045\001\045\001\018\001\045\001\045\001\021\001\
\022\001\002\001\003\001\045\001\045\001\007\001\045\001\008\001\
\045\001\047\002\048\002\049\002\050\002\015\001\045\001\045\001\
\018\001\018\001\047\001\044\001\002\001\045\001\008\001\045\001\
\045\001\047\001\048\001\045\001\066\002\067\002\007\001\069\002\
\054\001\047\001\056\001\057\001\047\001\059\001\015\001\041\001\
\042\001\018\001\047\001\045\001\045\001\001\001\047\001\048\001\
\002\001\051\001\042\001\042\001\054\001\007\000\056\001\057\001\
\018\001\059\001\014\000\021\001\022\001\032\000\166\000\211\000\
\041\001\042\001\164\001\215\001\045\001\201\001\024\001\025\001\
\026\001\027\001\051\001\221\002\158\001\054\001\165\002\056\001\
\057\001\140\002\059\001\045\001\012\001\039\001\040\001\195\001\
\032\002\051\001\044\001\079\002\054\001\243\001\056\001\057\001\
\123\001\028\000\121\001\137\002\138\002\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\091\000\125\001\035\001\019\002\019\002\044\001\255\255\046\001\
\028\001\029\001\030\001\031\001\032\001\255\255\034\001\035\001\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\044\001\255\255\046\001\255\255\255\255\255\255\069\001\255\255\
\028\001\029\001\030\001\031\001\032\001\255\255\034\001\035\001\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\044\001\069\001\046\001"

let yynames_const = "\
  ROLE\000\
  INIT\000\
  ACCEPT\000\
  IKNOWLEDGE\000\
  END\000\
  LOCAL\000\
  OWNS\000\
  CONST\000\
  CONS\000\
  DELETE\000\
  NEW\000\
  TRANSITION\000\
  GOAL\000\
  LOOP\000\
  AND\000\
  PRIME\000\
  UNDERSCORE\000\
  IMPLIES\000\
  OR\000\
  LTL_op1\000\
  LTL_op2\000\
  LTL_op3\000\
  LTL_op4\000\
  LTL_op5\000\
  AGENT\000\
  CHANNEL\000\
  PUBLIC_KEY\000\
  TEXT\000\
  MESSAGE\000\
  HASH\000\
  HASH_FUNC\000\
  NAT\000\
  PROTOCOL_ID\000\
  BOOL\000\
  SYMMETRIC_KEY\000\
  IN\000\
  NOT\000\
  ACTION_ARROW\000\
  REACTION_ARROW\000\
  FUNCTION_ARROW\000\
  L_PAR\000\
  R_PAR\000\
  L_BRACE\000\
  R_BRACE\000\
  COMMA\000\
  COLON\000\
  SEMI_COLON\000\
  DOT\000\
  DEF_EQUAL\000\
  PLUS\000\
  EQUAL\000\
  ASSIGN\000\
  LEQ\000\
  NEQ\000\
  PLAYED_BY\000\
  COMPOSITION\000\
  SECRECY_OF\000\
  AUTHENTICATES\000\
  AUTHENTICATION_ON\000\
  WEAKLY\000\
  WEAK_AUTHENTICATION_ON\000\
  ON\000\
  DY\000\
  OTA\000\
  SET\000\
  INV\000\
  START\000\
  "

let yynames_block = "\
  VAR_IDENT\000\
  CONST_IDENT\000\
  NAT_IDENT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'err01) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Role_definitions) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'Maybe_goal_declaration) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Role_instantiation) in
    Obj.repr(
# 157 "parser.mly"
  ( new Types.specification_class _2 _3 _4 )
# 1034 "parser.ml"
               : Types.specification_class))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Role_definition) in
    Obj.repr(
# 163 "parser.mly"
  ( Globals.current_role := 0;
    [_1] )
# 1042 "parser.ml"
               : 'Role_definitions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Role_definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Role_definitions) in
    Obj.repr(
# 166 "parser.mly"
  ( _1::_2 )
# 1050 "parser.ml"
               : 'Role_definitions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Basic_role) in
    Obj.repr(
# 177 "parser.mly"
  ( Types.Basic (_1) )
# 1057 "parser.ml"
               : 'Role_definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Composition_role) in
    Obj.repr(
# 179 "parser.mly"
  ( Types.Composition(_1) )
# 1064 "parser.ml"
               : 'Role_definition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'Role_header) in
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'err33) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'Player) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Role_declarations) in
    let _6 = (Parsing.peek_val __caml_parser_env 4 : 'err29) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'Maybe_transition_declaration) in
    let _10 = (Parsing.peek_val __caml_parser_env 0 : 'err01) in
    Obj.repr(
# 188 "parser.mly"
  ( let (name, formal_args) = _2 in
    let player = _4 in
    let (local, owns, init, accept, knowledge) = _5 in
    let role = new Types.basic_hlpsl_role in
    role#set_name name;
    role#set_player player;
    role#set_param formal_args;
    role#set_owned owns;
    role#set_local (local@(!newSetsDecl));
    role#set_init (init@(!newSetsInit));
    role#set_accept accept;
    role#set_knowledge knowledge;
    role#set_actions _7;
    Globals.player_to_role:=(player,name)::(!Globals.player_to_role);
    check_player_of_role player name formal_args;
    role
  )
# 1093 "parser.ml"
               : 'Basic_role))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err03) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 209 "parser.mly"
  ( Globals.string_id#register_name _3 !Globals.current_role )
# 1101 "parser.ml"
               : 'Player))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : 'Role_header) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'Role_declarations) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : 'err30) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'Maybe_composition_declaration) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : 'err01) in
    Obj.repr(
# 218 "parser.mly"
  ( let (name, formal_args) = _2 in
    let (local, owns, init, accept, knowledge) = _3 in
    let role = new Types.composition_role _5 in
    role#set_name name;
    role#set_param formal_args;
    role#set_owned owns;
    role#set_local (local@(!newSetsDecl));
    role#set_init (init@(!newSetsInit));
    role#set_accept accept;
    role#set_knowledge knowledge;
    role
  )
# 1123 "parser.ml"
               : 'Composition_role))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : 'Role_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err202) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Maybe_formal_arguments) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 235 "parser.mly"
  ( newSetsInfo:=[];
    newSetsInit:=[];
    newSetsDecl:=[];
    (_1,_5) )
# 1137 "parser.ml"
               : 'Role_header))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err37) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 243 "parser.mly"
  ( Globals.current_role := Globals.string_id#register_name _2 0;
    !Globals.current_role
  )
# 1147 "parser.ml"
               : 'Role_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Formal_arguments) in
    Obj.repr(
# 270 "parser.mly"
  ( _1 )
# 1154 "parser.ml"
               : 'Maybe_formal_arguments))
; (fun __caml_parser_env ->
    Obj.repr(
# 271 "parser.mly"
  ( [] )
# 1160 "parser.ml"
               : 'Maybe_formal_arguments))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Variable_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err35) in
    Obj.repr(
# 276 "parser.mly"
  ( _1 )
# 1168 "parser.ml"
               : 'Formal_arguments))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Variable_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err35) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Formal_arguments) in
    Obj.repr(
# 278 "parser.mly"
  ( _1@_4 )
# 1177 "parser.ml"
               : 'Formal_arguments))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 13 : 'err06) in
    let _3 = (Parsing.peek_val __caml_parser_env 11 : 'err13) in
    let _4 = (Parsing.peek_val __caml_parser_env 10 : 'Maybe_local_declaration) in
    let _5 = (Parsing.peek_val __caml_parser_env 9 : 'err12) in
    let _6 = (Parsing.peek_val __caml_parser_env 8 : 'Maybe_owns_declaration) in
    let _7 = (Parsing.peek_val __caml_parser_env 7 : 'err36) in
    let _8 = (Parsing.peek_val __caml_parser_env 6 : 'Maybe_const_declaration) in
    let _9 = (Parsing.peek_val __caml_parser_env 5 : 'err14) in
    let _10 = (Parsing.peek_val __caml_parser_env 4 : 'Maybe_init_declaration) in
    let _11 = (Parsing.peek_val __caml_parser_env 3 : 'err15) in
    let _12 = (Parsing.peek_val __caml_parser_env 2 : 'Maybe_accept_declaration) in
    let _13 = (Parsing.peek_val __caml_parser_env 1 : 'err32) in
    let _14 = (Parsing.peek_val __caml_parser_env 0 : 'Maybe_iknowledge_declaration) in
    Obj.repr(
# 290 "parser.mly"
  ( (_4,_6,_10,_12,_14) (* WARNING: const declarations not taken into account *) )
# 1196 "parser.ml"
               : 'Role_declarations))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Local_declaration) in
    Obj.repr(
# 319 "parser.mly"
  ( _2 )
# 1203 "parser.ml"
               : 'Maybe_local_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 320 "parser.mly"
  ( [] )
# 1209 "parser.ml"
               : 'Maybe_local_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Variables_declaration_list) in
    Obj.repr(
# 325 "parser.mly"
  ( _1 )
# 1216 "parser.ml"
               : 'Local_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Variable_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err351) in
    Obj.repr(
# 330 "parser.mly"
  ( _1 )
# 1224 "parser.ml"
               : 'Variables_declaration_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Variable_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err351) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Variables_declaration_list) in
    Obj.repr(
# 332 "parser.mly"
  ( _1@_4 )
# 1233 "parser.ml"
               : 'Variables_declaration_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Owns_declaration) in
    Obj.repr(
# 344 "parser.mly"
  ( _2 )
# 1240 "parser.ml"
               : 'Maybe_owns_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 345 "parser.mly"
  ( [] )
# 1246 "parser.ml"
               : 'Maybe_owns_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Variables_list) in
    Obj.repr(
# 350 "parser.mly"
  ( List.fold_left
      (fun lv var -> 
	try
	  (lv@[new Types.hlpsl_variable var (Globals.type_table#get_type var)])
	with
	  Not_found ->
	    (Semantic_check.add_sem_error
	     (19,
	      Globals.string_id#get_name var,
	      line_number(),
	      Globals.string_id#get_name !Globals.current_role,
	      "","");
	     lv))
      [] _1 
  )
# 1267 "parser.ml"
               : 'Owns_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Const_declaration) in
    Obj.repr(
# 370 "parser.mly"
  ()
# 1274 "parser.ml"
               : 'Maybe_const_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 371 "parser.mly"
  ()
# 1280 "parser.ml"
               : 'Maybe_const_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_declaration_list) in
    Obj.repr(
# 376 "parser.mly"
  ()
# 1287 "parser.ml"
               : 'Const_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Constant_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err352) in
    Obj.repr(
# 381 "parser.mly"
  ()
# 1295 "parser.ml"
               : 'Constants_declaration_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Constant_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err352) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_declaration_list) in
    Obj.repr(
# 383 "parser.mly"
  ()
# 1304 "parser.ml"
               : 'Constants_declaration_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Init_declarations) in
    Obj.repr(
# 395 "parser.mly"
  ( List.iter
      (fun (xid,l) ->
	let setType =
	  let rec find_applied = function
	      t::lt ->
		(try
		  Set([Utils.term_to_type t])
		with Not_found -> find_applied lt)
	    | [] -> Set([])
	  in
	  find_applied l
	in
	ignore (Globals.type_table#register_type xid setType);
	newSetsDecl := !newSetsDecl @ [new Types.hlpsl_variable xid setType];
	newSetsInit := !newSetsInit @ [Types.Equal(Types.Base(Types.Var(xid)),Set(l))])
      !newSetsInfo;
    newSetsInfo:=[];
    _2 )
# 1328 "parser.ml"
               : 'Maybe_init_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 413 "parser.mly"
  ([])
# 1334 "parser.ml"
               : 'Maybe_init_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Init_declaration) in
    Obj.repr(
# 418 "parser.mly"
  ( [_1] )
# 1341 "parser.ml"
               : 'Init_declarations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'Init_declaration) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Init_declarations) in
    Obj.repr(
# 420 "parser.mly"
  ( _1::_3 )
# 1349 "parser.ml"
               : 'Init_declarations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err243) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 425 "parser.mly"
  ( match _5 with
    Types.Base(Types.Var(xid)) ->
      if List.mem_assoc xid !newSetsInfo then
	(let l = List.assoc xid !newSetsInfo in
	newSetsInfo := List.remove_assoc xid !newSetsInfo;
	Types.Equal(Types.Base(Types.Var(Globals.string_id#register_name _1 !Globals.current_role)), Set(l)))
      else
	Types.Equal(Types.Base(Types.Var(Globals.string_id#register_name _1 !Globals.current_role)), _5)
  | _ -> Types.Equal(Types.Base(Types.Var(Globals.string_id#register_name _1 !Globals.current_role)),_5) )
# 1367 "parser.ml"
               : 'Init_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 435 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),[]) )
# 1376 "parser.ml"
               : 'Init_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 437 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),_5) )
# 1387 "parser.ml"
               : 'Init_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Concatenated_variables_list) in
    Obj.repr(
# 446 "parser.mly"
  ( (* \fix{To be implemented} *) 
    (new 
       Types.call_over_declaration 0
         (dummy_val_of_type (Types.Base(Types.Text))))
  )
# 1398 "parser.ml"
               : 'Parameters_instance))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'Concatenated_variables_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 452 "parser.mly"
  (
    let string_var = 
      match _7 with
        Types.Base(Types.Var i) -> i
      | _ -> 
	  Error_handler.errorNumber := 20;
	  raise Parse_error()
    in
    new Types.call_over_declaration string_var _4
  )
# 1418 "parser.ml"
               : 'Parameters_instance))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Concatenated_variables) in
    Obj.repr(
# 466 "parser.mly"
  ( _1 )
# 1425 "parser.ml"
               : 'Concatenated_variables_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Concatenated_variables) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 468 "parser.mly"
  ( _2 )
# 1433 "parser.ml"
               : 'Concatenated_variables_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err03) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 474 "parser.mly"
  ( Types.Base (Types.Var (Globals.string_id#register_name _2 !Globals.current_role)) )
# 1441 "parser.ml"
               : 'Concatenated_variables))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err03) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'err19) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Concatenated_variables) in
    Obj.repr(
# 476 "parser.mly"
  ( Pair(Types.Base (Types.Var (Globals.string_id#register_name _2 !Globals.current_role)), _5) )
# 1451 "parser.ml"
               : 'Concatenated_variables))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Accept_declaration) in
    Obj.repr(
# 496 "parser.mly"
  ( _2 )
# 1458 "parser.ml"
               : 'Maybe_accept_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 497 "parser.mly"
  ( [] )
# 1464 "parser.ml"
               : 'Maybe_accept_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err21) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Predicates) in
    Obj.repr(
# 502 "parser.mly"
  ( _2 )
# 1472 "parser.ml"
               : 'Accept_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'IKnowledge_declaration) in
    Obj.repr(
# 526 "parser.mly"
  ( let newSetKnlg =
      (List.map
	 (fun (xid,l) ->
	   let setType =
	     let rec find_applied = function
		 t::lt ->
		   (try
		     Set([Utils.term_to_type t])
		   with Not_found -> find_applied lt)
	       | [] -> Set([])
	     in
	     find_applied l
	   in
	   ignore (Globals.type_table#register_type xid setType);
	   newSetsInit := !newSetsInit @ [Types.Equal(Types.Base(Types.Var(xid)),Set(l))];
	   Types.Base(Types.Var(xid)))
	 !newSetsInfo)
    in
    newSetsInfo:=[];
    _1 @ newSetKnlg )
# 1498 "parser.ml"
               : 'Maybe_iknowledge_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 546 "parser.mly"
  ( [] )
# 1504 "parser.ml"
               : 'Maybe_iknowledge_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err242) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err09) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err316) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err08) in
    Obj.repr(
# 551 "parser.mly"
  ( _7 )
# 1515 "parser.ml"
               : 'IKnowledge_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err242) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err09) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err08) in
    Obj.repr(
# 553 "parser.mly"
  ( [] )
# 1524 "parser.ml"
               : 'IKnowledge_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err16) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'Transitions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'err02) in
    Obj.repr(
# 566 "parser.mly"
  ( _3 )
# 1533 "parser.ml"
               : 'Maybe_transition_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err02) in
    Obj.repr(
# 568 "parser.mly"
  ( [] )
# 1540 "parser.ml"
               : 'Maybe_transition_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err161) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Transition) in
    Obj.repr(
# 573 "parser.mly"
  ( [_2] )
# 1548 "parser.ml"
               : 'Transitions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'err161) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'Transition) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Transitions_list) in
    Obj.repr(
# 575 "parser.mly"
  ( _2::_3 )
# 1557 "parser.ml"
               : 'Transitions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'Label) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err19) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err21) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : 'Predicates) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err18) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err38) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Actions) in
    Obj.repr(
# 580 "parser.mly"
  ( let newSetCons =
      (List.map
	 (fun (xid,l) ->
	   let setType =
	     let rec find_applied = function
		 t::lt ->
		   (try
		     Set([Utils.term_to_type t])
		   with Not_found -> find_applied lt)
	       | [] -> Set([])
	     in
	     find_applied l
	   in
	   ignore (Globals.type_table#register_type xid setType);
	   newSetsDecl := !newSetsDecl@[new Types.hlpsl_variable xid setType];
	   newSetsInit := !newSetsInit@[Types.Equal(Types.Base(Types.Var(xid)),Set([]))];
	   let rec makeCons = function
	       [] -> Types.Base(Types.Var(xid))
	     | t::lt ->
		 Types.Cons(t, makeCons lt)
	   in
	   Types.Equal(Types.Prime(Types.Var(xid)), makeCons l))
	 !newSetsInfo)
    in
    newSetsInfo:=[];
    (true, new Types.hlpsl_transition _1 _5 (_9 @ newSetCons)) )
# 1595 "parser.ml"
               : 'Transition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'Label) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err19) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err21) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : 'Events) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err18) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err38) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Reactions) in
    Obj.repr(
# 607 "parser.mly"
  ( let newSetCons =
      (List.map
	 (fun (xid,l) ->
	   let setType =
	     let rec find_applied = function
		 t::lt ->
		   (try
		     Set([Utils.term_to_type t])
		   with Not_found -> find_applied lt)
	       | [] -> Set([])
	     in
	     find_applied l
	   in
	   ignore (Globals.type_table#register_type xid setType);
	   newSetsDecl := !newSetsDecl@[new Types.hlpsl_variable xid setType];
	   newSetsInit := !newSetsInit@[Types.Equal(Types.Base(Types.Var(xid)),Set([]))];
	   let rec makeCons = function
	       [] -> Types.Base(Types.Var(xid))
	     | t::lt ->
		 Types.Cons(t, makeCons lt)
	   in
	   Types.Equal(Types.Prime(Types.Var(xid)), makeCons l))
	 !newSetsInfo)
    in
    newSetsInfo:=[];
    (false, new Types.hlpsl_transition _1 _5 (_9 @ newSetCons)) )
# 1633 "parser.ml"
               : 'Transition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 637 "parser.mly"
  ( Globals.string_id#register_name _1 0 )
# 1640 "parser.ml"
               : 'Label))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 639 "parser.mly"
  ( Globals.string_id#register_name _1 0 )
# 1647 "parser.ml"
               : 'Label))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Predicate) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err22) in
    Obj.repr(
# 645 "parser.mly"
  ( if !newSetsInfo <> [] then
      (Error_handler.errorNumber := 251;
       raise Parse_error());
    [_1] )
# 1658 "parser.ml"
               : 'Predicates))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Predicate) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err22) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err21) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Predicates) in
    Obj.repr(
# 650 "parser.mly"
  ( _1::_5 )
# 1668 "parser.ml"
               : 'Predicates))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_formula) in
    Obj.repr(
# 655 "parser.mly"
  ( _1 )
# 1675 "parser.ml"
               : 'Predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 657 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),[]) )
# 1684 "parser.ml"
               : 'Predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 659 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),_5) )
# 1695 "parser.ml"
               : 'Predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 661 "parser.mly"
  ( Types.Event(Types.Var (Globals.string_id#register_name _1 !Globals.current_role),_5) )
# 1706 "parser.ml"
               : 'Predicate))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Predicate) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 663 "parser.mly"
  ( Types.Not(_5) )
# 1716 "parser.ml"
               : 'Predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Predicate) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err22) in
    Obj.repr(
# 675 "parser.mly"
  ( if !newSetsInfo <> [] then
      (Error_handler.errorNumber := 251;
       raise Parse_error());
    [_1] )
# 1727 "parser.ml"
               : 'Events))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Event) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err22) in
    Obj.repr(
# 680 "parser.mly"
  ( if !newSetsInfo <> [] then
      (Error_handler.errorNumber := 251;
       raise Parse_error());
    [_1] )
# 1738 "parser.ml"
               : 'Events))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Predicate) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err22) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err21) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Events) in
    Obj.repr(
# 685 "parser.mly"
  ( _1::_5 )
# 1748 "parser.ml"
               : 'Events))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Event) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err22) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err21) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Events) in
    Obj.repr(
# 687 "parser.mly"
  ( _1::_5 )
# 1758 "parser.ml"
               : 'Events))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_formula) in
    Obj.repr(
# 692 "parser.mly"
  ( _1 )
# 1765 "parser.ml"
               : 'Event))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 694 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),_5) )
# 1776 "parser.ml"
               : 'Event))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 696 "parser.mly"
  ( Types.Event(Types.Var (Globals.string_id#register_name _1 !Globals.current_role),_5) )
# 1787 "parser.ml"
               : 'Event))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 698 "parser.mly"
  ( Globals.global_start_const := true;
    Globals.register_start();
    Types.Event
      (Types.Var (Globals.string_id#register_name _1 !Globals.current_role),
       [Types.Base
	  (Types.Const 
	     !Globals.global_start)]) )
# 1802 "parser.ml"
               : 'Event))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Event) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 706 "parser.mly"
  ( Types.Not(_5) )
# 1812 "parser.ml"
               : 'Event))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Action) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err16) in
    Obj.repr(
# 712 "parser.mly"
  ( [_1] )
# 1820 "parser.ml"
               : 'Actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Action) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err16) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Actions) in
    Obj.repr(
# 714 "parser.mly"
  ( _1::_4 )
# 1829 "parser.ml"
               : 'Actions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Actions) in
    Obj.repr(
# 719 "parser.mly"
  ( _1 )
# 1836 "parser.ml"
               : 'Reactions))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err23) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err243) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : 'Expression) in
    Obj.repr(
# 724 "parser.mly"
  ( 
    Types.Equal
      (Types.Prime
	 (Types.Var
	    (Globals.string_id#register_name _1 !Globals.current_role)),
       _7)
  )
# 1853 "parser.ml"
               : 'Action))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 10 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 9 : 'err23) in
    let _4 = (Parsing.peek_val __caml_parser_env 7 : 'err243) in
    let _6 = (Parsing.peek_val __caml_parser_env 5 : 'err312) in
    let _8 = (Parsing.peek_val __caml_parser_env 3 : 'err23) in
    let _10 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 732 "parser.mly"
  ( 
    Types.New
      (Globals.string_id#register_name _1 !Globals.current_role)
  )
# 1868 "parser.ml"
               : 'Action))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 740 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),[]) )
# 1877 "parser.ml"
               : 'Action))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 742 "parser.mly"
  ( Types.Event(Types.Const (Globals.string_id#register_name _1 0),_5) )
# 1888 "parser.ml"
               : 'Action))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 744 "parser.mly"
  ( Types.Event(Types.Var (Globals.string_id#register_name _1 !Globals.current_role),_5) )
# 1899 "parser.ml"
               : 'Action))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err28) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'Compositions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'err02) in
    Obj.repr(
# 750 "parser.mly"
  ( List.iter
      (fun (xid,l) ->
	let setType =
	  let rec find_applied = function
	      t::lt ->
		(try
		  Set([Utils.term_to_type t])
		with Not_found -> find_applied lt)
	    | [] -> Set([])
	  in
	  find_applied l
	in
	ignore (Globals.type_table#register_type xid setType);
	newSetsDecl := !newSetsDecl@[new Types.hlpsl_variable xid setType];
	newSetsInit := !newSetsInit@[Types.Equal(Types.Base(Types.Var(xid)),Set(l))])
      !newSetsInfo;
    newSetsInfo:=[];
    _3 )
# 1925 "parser.ml"
               : 'Maybe_composition_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err02) in
    Obj.repr(
# 769 "parser.mly"
  ( Types.Empty )
# 1932 "parser.ml"
               : 'Maybe_composition_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err201) in
    Obj.repr(
# 774 "parser.mly"
  ( _1 )
# 1940 "parser.ml"
               : 'Compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err201) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_par_compositions_list) in
    Obj.repr(
# 776 "parser.mly"
  ( Types.Parallel(_1,_4) )
# 1949 "parser.ml"
               : 'Compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err201) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_seq_compositions_list) in
    Obj.repr(
# 778 "parser.mly"
  ( Types.Sequential(_1,_4) )
# 1958 "parser.ml"
               : 'Compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Compositions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 780 "parser.mly"
  ( _3 )
# 1967 "parser.ml"
               : 'Compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Role_instance) in
    Obj.repr(
# 785 "parser.mly"
  ( _1 )
# 1974 "parser.ml"
               : 'Composition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err07) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err09) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'Parameters_instance) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : 'err08) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_compositions_list) in
    Obj.repr(
# 787 "parser.mly"
  (
   Types.MultiPar(_6,_9)
     (*
	match $8 with
	  Types.Parallel(r1,r2) ->
	    Types.MultiPar($5,$8)
	| Types.Sequential(r1,r2) ->
	    Types.MultiSeq($5,$8)
	| _ ->
	  Types.MultiPar($5,$8)
      *)
  )
# 1996 "parser.ml"
               : 'Composition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err201) in
    Obj.repr(
# 803 "parser.mly"
  ( _1 )
# 2004 "parser.ml"
               : 'Bracketed_par_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err201) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_par_compositions_list) in
    Obj.repr(
# 805 "parser.mly"
  ( Types.Parallel(_1,_4) )
# 2013 "parser.ml"
               : 'Bracketed_par_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Compositions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 807 "parser.mly"
  ( _3 )
# 2022 "parser.ml"
               : 'Bracketed_par_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err201) in
    Obj.repr(
# 812 "parser.mly"
  ( _1 )
# 2030 "parser.ml"
               : 'Bracketed_seq_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err201) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_seq_compositions_list) in
    Obj.repr(
# 814 "parser.mly"
  ( Types.Sequential(_1,_4) )
# 2039 "parser.ml"
               : 'Bracketed_seq_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Compositions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 816 "parser.mly"
  ( _3 )
# 2048 "parser.ml"
               : 'Bracketed_seq_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Composition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'err201) in
    Obj.repr(
# 821 "parser.mly"
  ( _1 )
# 2056 "parser.ml"
               : 'Bracketed_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Compositions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 823 "parser.mly"
  ( _3 )
# 2065 "parser.ml"
               : 'Bracketed_compositions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Role_instantiation) in
    Obj.repr(
# 829 "parser.mly"
  ( _1 )
# 2072 "parser.ml"
               : 'Role_instance))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : 'err37) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'Maybe_effective_arguments) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'err11) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : 'err201) in
    Obj.repr(
# 838 "parser.mly"
  ( (* \fix{what if no params?} *)
    Types.Call(new Types.call_type (Globals.string_id#register_name _2 0) _5)
  )
# 2086 "parser.ml"
               : 'Role_instantiation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Expressions_list) in
    Obj.repr(
# 845 "parser.mly"
  ( _1 )
# 2093 "parser.ml"
               : 'Maybe_effective_arguments))
; (fun __caml_parser_env ->
    Obj.repr(
# 846 "parser.mly"
  ( [] )
# 2099 "parser.ml"
               : 'Maybe_effective_arguments))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Goal_declaration) in
    Obj.repr(
# 852 "parser.mly"
  ( _1 )
# 2106 "parser.ml"
               : 'Maybe_goal_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 853 "parser.mly"
  ( [] )
# 2112 "parser.ml"
               : 'Maybe_goal_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Goal_formulas_list) in
    Obj.repr(
# 858 "parser.mly"
  ( _2 )
# 2119 "parser.ml"
               : 'Goal_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Goal_formula) in
    Obj.repr(
# 863 "parser.mly"
  ( [_1] )
# 2126 "parser.ml"
               : 'Goal_formulas_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Goal_formula) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Goal_formulas_list) in
    Obj.repr(
# 865 "parser.mly"
  ( _1::_2 )
# 2134 "parser.ml"
               : 'Goal_formulas_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : 'err05) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : 'err37) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'err37) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 885 "parser.mly"
  ( let rid1 = Globals.string_id#register_name _1 0 in
    let rid2 = Globals.string_id#register_name _5 0 in
    let sid1 = Globals.string_id#register_name "SID1" 0 in
    let sid1_type = Globals.type_table#register_type sid1 (Types.Base Types.Nat) in
    if sid1_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID1 has to be of type nat","","","","");
    let sid2 = Globals.string_id#register_name "SID2" 0 in
    let sid2_type = Globals.type_table#register_type sid2 (Types.Base Types.Nat) in
    if sid2_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID2 has to be of type nat","","","","");
    let mgoal = Globals.string_id#register_name "MGoal" 0 in
    let mgoal_type = Globals.type_table#register_type mgoal (Types.Base Types.Message) in
    if mgoal_type <> (Types.Base Types.Message) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable MGoal has to be of type message","","","","");
    Types.Auth (rid1,rid2,_8) )
# 2163 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err05) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : 'err37) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err37) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 904 "parser.mly"
  ( let rid1 = Globals.string_id#register_name _1 0 in
    let rid2 = Globals.string_id#register_name _6 0 in
    let mgoal = Globals.string_id#register_name "MGoal" 0 in
    let mgoal_type = Globals.type_table#register_type mgoal (Types.Base Types.Message) in
    if mgoal_type <> (Types.Base Types.Message) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable MGoal has to be of type message","","","","");
    Types.Weak_auth (rid1,rid2,_9) )
# 2182 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err27) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 915 "parser.mly"
  ( let mgoal = Globals.string_id#register_name "MGoal" 0 in
    let mgoal_type = Globals.type_table#register_type mgoal (Types.Base Types.Message) in
    if mgoal_type <> (Types.Base Types.Message) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable MGoal has to be of type message","","","","");
    let asgoal = Globals.string_id#register_name "ASGoal" 0 in
    let asgoal_type = Globals.type_table#register_type asgoal (Types.Set [Types.Base Types.Agent]) in
    if asgoal_type <> (Types.Set [Types.Base Types.Agent]) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable ASGoal has to be of type agent set","","","","");
    Types.Secrecy _3 )
# 2200 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err37) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 927 "parser.mly"
  ( let a1goal = Globals.string_id#register_name "A1Goal" 0 in
    let a1goal_type = Globals.type_table#register_type a1goal (Types.Base Types.Agent) in
    if a1goal_type <> (Types.Base Types.Agent) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable A1Goal has to be of type agent","","","","");
    let a2goal = Globals.string_id#register_name "A2Goal" 0 in
    let a2goal_type = Globals.type_table#register_type a2goal (Types.Base Types.Agent) in
    if a2goal_type <> (Types.Base Types.Agent) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable A2Goal has to be of type agent","","","","");
    let sid = Globals.string_id#register_name "SID" 0 in
    let sid_type = Globals.type_table#register_type sid (Types.Base Types.Nat) in
    if sid_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID has to be of type nat","","","","");
    let sid1 = Globals.string_id#register_name "SID1" 0 in
    let sid1_type = Globals.type_table#register_type sid1 (Types.Base Types.Nat) in
    if sid1_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID1 has to be of type nat","","","","");
    let sid2 = Globals.string_id#register_name "SID2" 0 in
    let sid2_type = Globals.type_table#register_type sid2 (Types.Base Types.Nat) in
    if sid2_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID2 has to be of type nat","","","","");
    let mgoal = Globals.string_id#register_name "MGoal" 0 in
    let mgoal_type = Globals.type_table#register_type mgoal (Types.Base Types.Message) in
    if mgoal_type <> (Types.Base Types.Message) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable MGoal has to be of type message","","","","");
    Types.Authentication (_3) )
# 2238 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err37) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 959 "parser.mly"
  ( let a1goal = Globals.string_id#register_name "A1Goal" 0 in
    let a1goal_type = Globals.type_table#register_type a1goal (Types.Base Types.Agent) in
    if a1goal_type <> (Types.Base Types.Agent) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable A1Goal has to be of type agent","","","","");
    let a2goal = Globals.string_id#register_name "A2Goal" 0 in
    let a2goal_type = Globals.type_table#register_type a2goal (Types.Base Types.Agent) in
    if a2goal_type <> (Types.Base Types.Agent) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable A2Goal has to be of type agent","","","","");
    let sid = Globals.string_id#register_name "SID" 0 in
    let sid_type = Globals.type_table#register_type sid (Types.Base Types.Nat) in
    if sid_type <> (Types.Base Types.Nat) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable SID has to be of type nat","","","","");
    let mgoal = Globals.string_id#register_name "MGoal" 0 in
    let mgoal_type = Globals.type_table#register_type mgoal (Types.Base Types.Message) in
    if mgoal_type <> (Types.Base Types.Message) then
      Semantic_check.add_sem_error
	(18,"pre-defined variable MGoal has to be of type message","","","","");
    Types.Weak_authentication (_3) )
# 2266 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 981 "parser.mly"
  ( if !newSetsInfo <> [] then
      (Error_handler.errorNumber := 252;
       raise Parse_error());
    Types.LTL_goal (Op1(_2), Utils.vars_consts_from_LTL_goal _2) )
# 2276 "parser.ml"
               : 'Goal_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_predicate) in
    Obj.repr(
# 989 "parser.mly"
  (Pred(_1))
# 2283 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 991 "parser.mly"
  (Op2(_2))
# 2290 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 993 "parser.mly"
  (Op3(_2))
# 2297 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 995 "parser.mly"
  (Op4(_2))
# 2304 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 997 "parser.mly"
  (Op5(_2))
# 2311 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_formula) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 999 "parser.mly"
  (_3)
# 2320 "parser.ml"
               : 'LTL_unary_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_predicate) in
    Obj.repr(
# 1004 "parser.mly"
  (Pred(_1))
# 2327 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 1006 "parser.mly"
  (Op2(_2))
# 2334 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 1008 "parser.mly"
  (Op3(_2))
# 2341 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 1010 "parser.mly"
  (Op4(_2))
# 2348 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_formula) in
    Obj.repr(
# 1012 "parser.mly"
  (Op5(_2))
# 2355 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_formula) in
    Obj.repr(
# 1014 "parser.mly"
  (Conj(_1,_3))
# 2363 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_formula) in
    Obj.repr(
# 1016 "parser.mly"
  (Dij(_1,_3))
# 2371 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_formula) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_formula) in
    Obj.repr(
# 1018 "parser.mly"
  (Impl(_1,_3))
# 2379 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_formula) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1020 "parser.mly"
  (_3)
# 2388 "parser.ml"
               : 'LTL_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1025 "parser.mly"
  ( Types.Unknown(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),[]) )
# 2397 "parser.ml"
               : 'LTL_unary_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1027 "parser.mly"
  ( Types.Unknown(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),_5) )
# 2408 "parser.ml"
               : 'LTL_unary_predicate))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Stutter_expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Variable_or_constant) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1029 "parser.mly"
  ( Types.Ifcontains(_5,_8) )
# 2420 "parser.ml"
               : 'LTL_unary_predicate))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'LTL_predicate) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1031 "parser.mly"
  ( Types.Ifnot(_4) )
# 2429 "parser.ml"
               : 'LTL_unary_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'LTL_unary_predicate) in
    Obj.repr(
# 1036 "parser.mly"
  (_1)
# 2436 "parser.ml"
               : 'LTL_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1038 "parser.mly"
  ( Types.Ifequal(_1,_4) )
# 2445 "parser.ml"
               : 'LTL_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1040 "parser.mly"
  ( Types.Ifleq(_1,_4) )
# 2454 "parser.ml"
               : 'LTL_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1042 "parser.mly"
  ( Types.Ifnot(Types.Ifequal(_1,_4)) )
# 2463 "parser.ml"
               : 'LTL_predicate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Variables_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err10) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Type_of) in
    Obj.repr(
# 1055 "parser.mly"
  ( List.map 
      (fun var ->
        if (Globals.type_table#register_type var _4) <> _4 then
	  (let error_string =
	    ("variable "^(Globals.string_id#get_name var)^
	     " redeclared with incompatible type")
	  in
	  Semantic_check.add_sem_error
	    (16, error_string, line_number(), "","",""));
        new Types.hlpsl_variable var _4)
      _1
  )
# 2483 "parser.ml"
               : 'Variable_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'err03) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'err702) in
    Obj.repr(
# 1072 "parser.mly"
  ( [Globals.string_id#register_name _2 !Globals.current_role] )
# 2492 "parser.ml"
               : 'Variables_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err03) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'err702) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Variables_list) in
    Obj.repr(
# 1074 "parser.mly"
  ( (Globals.string_id#register_name _2 !Globals.current_role)::_5 )
# 2502 "parser.ml"
               : 'Variables_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Subtype_of) in
    Obj.repr(
# 1087 "parser.mly"
  ( _1 )
# 2509 "parser.ml"
               : 'Type_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Type_of) in
    Obj.repr(
# 1089 "parser.mly"
  ( match _3 with
      Types.Function(r,lt) -> Types.Function(r,_1::lt)
    | _ -> Types.Function(_3,[_1])
  )
# 2520 "parser.ml"
               : 'Type_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_type) in
    Obj.repr(
# 1097 "parser.mly"
  ( Types.Base _1 )
# 2527 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1099 "parser.mly"
  ( _2 )
# 2535 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Subtype_of) in
    Obj.repr(
# 1101 "parser.mly"
  ( Types.Pair(_1,_3) )
# 2543 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'Subtype_of) in
    Obj.repr(
# 1109 "parser.mly"
  ( Types.Set [_1] )
# 2550 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'Subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'err08) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'err07) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_subtype_of) in
    Obj.repr(
# 1111 "parser.mly"
  ( match _7 with
    Base(Public_key)
  | Inv(Base(Public_key)) ->
      Types.Crypt(_2,_7)
  | _ ->
      Types.Scrypt(_2,_7) )
# 2565 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1118 "parser.mly"
  ( Types.Inv(_4) )
# 2574 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1120 "parser.mly"
  ( Types.Hash(_4) )
# 2583 "parser.ml"
               : 'Subtype_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_type) in
    Obj.repr(
# 1125 "parser.mly"
  ( Types.Base _1 )
# 2590 "parser.ml"
               : 'Bracketed_subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1127 "parser.mly"
  ( Types.Inv(_4) )
# 2599 "parser.ml"
               : 'Bracketed_subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1129 "parser.mly"
  ( _2 )
# 2607 "parser.ml"
               : 'Bracketed_subtype_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Constants_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err10) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_type_of) in
    Obj.repr(
# 1134 "parser.mly"
  ( List.iter
      (fun cst ->
         if (Globals.type_table#register_type cst _4) <> _4 then
	   let error_string =
	     ("constant "^(Globals.string_id#get_name cst)^
	      " redeclared with incompatible type")
	   in
	   Semantic_check.add_sem_error
	     (16, error_string, line_number(), "","",""))
      _1
  )
# 2626 "parser.ml"
               : 'Constant_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'err37) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'err701) in
    Obj.repr(
# 1149 "parser.mly"
  ( [Globals.string_id#register_name _2 0] )
# 2635 "parser.ml"
               : 'Constants_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err37) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'err701) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_list) in
    Obj.repr(
# 1151 "parser.mly"
  ( (Globals.string_id#register_name _2 0)::_5 )
# 2645 "parser.ml"
               : 'Constants_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_subtype_of) in
    Obj.repr(
# 1157 "parser.mly"
  ( _1 )
# 2652 "parser.ml"
               : 'Simple_type_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'Simple_subtype_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_type_of) in
    Obj.repr(
# 1159 "parser.mly"
  ( match _3 with
      Types.Function(r,lt) -> Types.Function(r,_1::lt)
    | _ -> Types.Function(_3,[_1])
  )
# 2663 "parser.ml"
               : 'Simple_type_of))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Simple_type) in
    Obj.repr(
# 1167 "parser.mly"
  ( Types.Base _1 )
# 2670 "parser.ml"
               : 'Simple_subtype_of))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Simple_type_of) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1169 "parser.mly"
  ( _2 )
# 2678 "parser.ml"
               : 'Simple_subtype_of))
; (fun __caml_parser_env ->
    Obj.repr(
# 1179 "parser.mly"
  ( Types.Agent )
# 2684 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1181 "parser.mly"
  ( Types.Channel )
# 2690 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'err34) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1183 "parser.mly"
  ( Types.Channel_dy )
# 2698 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'err34) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1185 "parser.mly"
  ( Types.Channel_ota )
# 2706 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1187 "parser.mly"
  ( Types.Public_key )
# 2712 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1189 "parser.mly"
  ( Types.Symmetric_key )
# 2718 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1191 "parser.mly"
  ( Types.Text )
# 2724 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1193 "parser.mly"
  ( Types.Message )
# 2730 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1195 "parser.mly"
  ( Types.Protocol_id )
# 2736 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1197 "parser.mly"
  ( Types.Nat )
# 2742 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1199 "parser.mly"
  ( Types.Bool )
# 2748 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1201 "parser.mly"
  ( Types.Hash_func )
# 2754 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'Constants_or_nat_list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err08) in
    Obj.repr(
# 1203 "parser.mly"
  ( Types.Enum _2 )
# 2762 "parser.ml"
               : 'Simple_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1208 "parser.mly"
  ( [Globals.string_id#register_name _1 0] )
# 2769 "parser.ml"
               : 'Constants_or_nat_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1210 "parser.mly"
  ( let name = Globals.string_id#register_name  _1 0 in
    ignore (Globals.type_table#register_type name (Types.Base Types.Nat));
    [name] )
# 2778 "parser.ml"
               : 'Constants_or_nat_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_or_nat_list) in
    Obj.repr(
# 1214 "parser.mly"
  ( (Globals.string_id#register_name _1 0)::_3 )
# 2786 "parser.ml"
               : 'Constants_or_nat_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'Constants_or_nat_list) in
    Obj.repr(
# 1216 "parser.mly"
  ( let name = Globals.string_id#register_name  _1 0 in
    ignore (Globals.type_table#register_type name (Types.Base Types.Nat));
    name::_3 )
# 2796 "parser.ml"
               : 'Constants_or_nat_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1224 "parser.mly"
  ( Types.Equal(_1,_5) )
# 2806 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err313) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1226 "parser.mly"
  ( Types.Leq(_1,_5) )
# 2816 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Stutter_expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1228 "parser.mly"
  ( Types.In(_5,_8) )
# 2828 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Non_stutter_expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1230 "parser.mly"
  ( Types.In(_5,_8) )
# 2840 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err314) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1232 "parser.mly"
  ( Types.Not(Types.Equal(_1,_5)) )
# 2850 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_formula) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1238 "parser.mly"
  ( _3 )
# 2859 "parser.ml"
               : 'Stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1243 "parser.mly"
  ( Types.Equal(_1,_5) )
# 2869 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1245 "parser.mly"
  ( Types.Equal(_1,_5) )
# 2879 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err312) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1247 "parser.mly"
  ( Types.Equal(_1,_5) )
# 2889 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err313) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1249 "parser.mly"
  ( Types.Leq(_1,_5) )
# 2899 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err313) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1251 "parser.mly"
  ( Types.Leq(_1,_5) )
# 2909 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err313) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1253 "parser.mly"
  ( Types.Leq(_1,_5) )
# 2919 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Non_stutter_expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1255 "parser.mly"
  ( Types.In(_5,_8) )
# 2931 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Stutter_expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1257 "parser.mly"
  ( Types.In(_5,_8) )
# 2943 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err314) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1259 "parser.mly"
  ( Types.Not(Types.Equal(_1,_5)) )
# 2953 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err314) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1261 "parser.mly"
  ( Types.Not(Types.Equal(_1,_5)) )
# 2963 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'Non_stutter_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err241) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err314) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1263 "parser.mly"
  ( Types.Not(Types.Equal(_1,_5)) )
# 2973 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_formula) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1269 "parser.mly"
  ( _3 )
# 2982 "parser.ml"
               : 'Non_stutter_formula))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1275 "parser.mly"
  ( [_2] )
# 2990 "parser.ml"
               : 'Stutter_expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err311) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expressions_list) in
    Obj.repr(
# 1277 "parser.mly"
  ( _2::_5 )
# 3000 "parser.ml"
               : 'Stutter_expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1282 "parser.mly"
  ( [_2] )
# 3008 "parser.ml"
               : 'Non_stutter_expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'Non_stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err311) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Expressions_list) in
    Obj.repr(
# 1284 "parser.mly"
  ( _2::_5 )
# 3018 "parser.ml"
               : 'Non_stutter_expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err311) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expressions_list) in
    Obj.repr(
# 1286 "parser.mly"
  ( _2::_5 )
# 3028 "parser.ml"
               : 'Non_stutter_expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'Expression) in
    Obj.repr(
# 1291 "parser.mly"
  ( [_2] )
# 3036 "parser.ml"
               : 'Expressions_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'err27) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'Expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err311) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'Expressions_list) in
    Obj.repr(
# 1293 "parser.mly"
  ( _2::_5 )
# 3046 "parser.ml"
               : 'Expressions_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1299 "parser.mly"
  ( _3 )
# 3055 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1301 "parser.mly"
  ( Types.Inv _5 )
# 3065 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err317) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1303 "parser.mly"
  ( Types.Pair(_1,_4) )
# 3074 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1324 "parser.mly"
  ( Types.Function(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),_5) )
# 3085 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1326 "parser.mly"
  ( Types.Function(Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)),_5) )
# 3096 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Variable_or_constant_or_nat) in
    Obj.repr(
# 1328 "parser.mly"
  ( _1 )
# 3103 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err08) in
    Obj.repr(
# 1330 "parser.mly"
  (
(*prerr_string "***SET: "; Interface.prerr_term (Types.Set([])); prerr_newline();
     Types.Set([]) *)
   let xid = Globals.string_id#register_blind_var "Set" !Globals.current_role in
   newSetsInfo := !newSetsInfo@[(xid,[])];
   Types.Base(Types.Var(xid)) )
# 3115 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err316) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expressions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'err08) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'err07) in
    Obj.repr(
# 1337 "parser.mly"
  (
(*prerr_string "***SET: "; Interface.prerr_term (Types.Set($3)); prerr_newline();
   Types.Set($3) *)
   let xid = Globals.string_id#register_blind_var "Set" !Globals.current_role in
   newSetsInfo := !newSetsInfo@[(xid,_3)];
   Types.Base(Types.Var(xid)) )
# 3130 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err316) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : 'Stutter_expressions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err08) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err07) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err315) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_stutter_expression) in
    Obj.repr(
# 1344 "parser.mly"
  ( match _3 with
      [e] ->
	(match _9 with
	  Types.Inv _ ->
 	    Types.Crypt(e,_9)
	| Types.Base (Types.Var i | Types.Const i) ->
	    (try
	      let t =
		(try
		  Globals.type_table#get_type i
		with Not_found ->
		  if !Globals.current_role = 0 then
		    Globals.get_any_type_of i
		  else
		    raise Not_found)
	      in
	      match t with
		Base(Public_key)
	      | Inv(Base(Public_key)) ->
		  Types.Crypt(e,_9)
	      | _ ->
		  Types.Scrypt(e,_9)
	    with Not_found ->
	      (Semantic_check.add_sem_error
		 (16,
		  ("cannot infer type of variable/constant "^(Globals.string_id#get_name i)),
		  line_number (),"","","");
	       Types.Scrypt(e,_9)))
(*TODO: The key may be the result of a function call
   Rmk: this can be avoided by writing:  K'=F(A) and {...}K' *)
	| _ -> Types.Scrypt(e,_9))
    | _ ->
	Error_handler.errorNumber := 901;
	raise Parsing.Parse_error
  )
# 3176 "parser.ml"
               : 'Stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1383 "parser.mly"
  ( _3 )
# 3185 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err23) in
    Obj.repr(
# 1385 "parser.mly"
  ( Types.Prime (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)) )
# 3193 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1387 "parser.mly"
  ( Types.Inv _5 )
# 3203 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Non_stutter_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err317) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1389 "parser.mly"
  ( Types.Pair(_1,_4) )
# 3212 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Stutter_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err317) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1391 "parser.mly"
  ( Types.Pair(_1,_4) )
# 3221 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'Non_stutter_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'err317) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1393 "parser.mly"
  ( Types.Pair(_1,_4) )
# 3230 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1402 "parser.mly"
  ( Types.Function(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),_5) )
# 3241 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1404 "parser.mly"
  ( Types.Function(Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)),_5) )
# 3252 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1406 "parser.mly"
  ( Types.Cons(_5,_8) )
# 3264 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'Expression) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'err311) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'Expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1408 "parser.mly"
  ( Types.Delete(_5,_8) )
# 3276 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'err316) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'Non_stutter_expressions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'err08) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'err07) in
    Obj.repr(
# 1410 "parser.mly"
  ( 
(*prerr_string "***SET: "; Interface.prerr_term (Types.Set($3)); prerr_newline();
    Types.Set($3)  *)
   let xid = Globals.string_id#register_blind_var "Set" !Globals.current_role in
   newSetsInfo := !newSetsInfo@[(xid,_3)];
   Types.Base(Types.Var(xid)) )
# 3291 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err316) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : 'Non_stutter_expressions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err08) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err07) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err315) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_expression) in
    Obj.repr(
# 1417 "parser.mly"
  ( match _3 with
      [e] ->
	(match _9 with
	  Types.Inv _ ->
 	    Types.Crypt(e,_9)
	| Types.Base (Types.Var i | Types.Const i)    
	| Types.Prime (Types.Var i | Types.Const i)  ->
	    (try
	      match (Globals.type_table#get_type i) with
		Base(Public_key)
	      | Inv(Base(Public_key)) ->
		  Types.Crypt(e,_9)
	      | _ ->
		  Types.Scrypt(e,_9)
	    with Not_found ->
	      (Semantic_check.add_sem_error
		 (16,
		  ("cannot infer type of variable/constant "^(Globals.string_id#get_name i)),
		  line_number (),"","","");
	       Types.Scrypt(e,_9)))
(*TODO: The key may be the result of a function call
   Rmk: this can be avoided by writing:  K'=F(A) and {...}K' *)
	| _ -> Types.Scrypt(e,_9))
    | _ ->
	Error_handler.errorNumber := 901;
	raise Parsing.Parse_error
  )
# 3329 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 7 : 'err316) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : 'Stutter_expressions_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'err08) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'err07) in
    let _8 = (Parsing.peek_val __caml_parser_env 1 : 'err315) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_non_stutter_expression) in
    Obj.repr(
# 1445 "parser.mly"
  ( match _3 with
      [e] ->
	(match _9 with
	  Types.Inv _ ->
 	    Types.Crypt(e,_9)
	| Types.Base (Types.Var i | Types.Const i)    
	| Types.Prime (Types.Var i | Types.Const i)  ->
	    (try
	      match (Globals.type_table#get_type i) with
		Base(Public_key)
	      | Inv(Base(Public_key)) ->
		  Types.Crypt(e,_9)
	      | _ ->
		  Types.Scrypt(e,_9)
	    with Not_found ->
	      (Semantic_check.add_sem_error
		 (16,
		  ("cannot infer type of variable/constant "^(Globals.string_id#get_name i)),
		  line_number (),"","","");
	       Types.Scrypt(e,_9)))
(*TODO: The key may be the result of a function call
   Rmk: this can be avoided by writing:  K'=F(A) and {...}K' *)
	| _ -> Types.Scrypt(e,_9))
    | _ ->
	Error_handler.errorNumber := 901;
	raise Parsing.Parse_error
  )
# 3367 "parser.ml"
               : 'Non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Stutter_expression) in
    Obj.repr(
# 1476 "parser.mly"
  ( _1 )
# 3374 "parser.ml"
               : 'Expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Non_stutter_expression) in
    Obj.repr(
# 1478 "parser.mly"
  ( _1 )
# 3381 "parser.ml"
               : 'Expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1483 "parser.mly"
  ( Types.Inv _5 )
# 3391 "parser.ml"
               : 'Bracketed_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1485 "parser.mly"
  ( Types.Function(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),_5) )
# 3402 "parser.ml"
               : 'Bracketed_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1487 "parser.mly"
  ( Types.Function(Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)),_5) )
# 3413 "parser.ml"
               : 'Bracketed_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Variable_or_constant_or_nat) in
    Obj.repr(
# 1489 "parser.mly"
  ( _1 )
# 3420 "parser.ml"
               : 'Bracketed_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1491 "parser.mly"
  ( _3 )
# 3429 "parser.ml"
               : 'Bracketed_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'err23) in
    Obj.repr(
# 1496 "parser.mly"
  ( Types.Prime 
      (Types.Var 
	 (Globals.string_id#register_name _1 !Globals.current_role))
  )
# 3440 "parser.ml"
               : 'Bracketed_non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1501 "parser.mly"
  ( Types.Inv _5 )
# 3450 "parser.ml"
               : 'Bracketed_non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1503 "parser.mly"
  ( Types.Function(Types.Base (Types.Const (Globals.string_id#register_name _1 0)),_5) )
# 3461 "parser.ml"
               : 'Bracketed_non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'err04) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expressions_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1505 "parser.mly"
  ( Types.Function(Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)),_5) )
# 3472 "parser.ml"
               : 'Bracketed_non_stutter_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'err31) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'Non_stutter_expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'err11) in
    Obj.repr(
# 1507 "parser.mly"
  ( _3 )
# 3481 "parser.ml"
               : 'Bracketed_non_stutter_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_stutter_expression) in
    Obj.repr(
# 1512 "parser.mly"
  ( _1 )
# 3488 "parser.ml"
               : 'Bracketed_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'Bracketed_non_stutter_expression) in
    Obj.repr(
# 1514 "parser.mly"
  ( _1 )
# 3495 "parser.ml"
               : 'Bracketed_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1520 "parser.mly"
  ( Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)) )
# 3502 "parser.ml"
               : 'Variable_or_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1522 "parser.mly"
  ( Types.Base (Types.Const (Globals.string_id#register_name _1 0)) )
# 3509 "parser.ml"
               : 'Variable_or_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1527 "parser.mly"
  ( Types.Base (Types.Var (Globals.string_id#register_name _1 !Globals.current_role)) )
# 3516 "parser.ml"
               : 'Variable_or_constant_or_nat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1529 "parser.mly"
  ( let name = Globals.string_id#register_name _1 0 in
    (try ignore (Globals.type_table#get_type name)
    with _ -> ());
    Types.Base (Types.Const name) )
# 3526 "parser.ml"
               : 'Variable_or_constant_or_nat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1534 "parser.mly"
  ( let name = Globals.string_id#register_name _1 0 in
    ignore (Globals.type_table#register_type name (Types.Base Types.Nat));
    Types.Base (Types.Const name)
  )
# 3536 "parser.ml"
               : 'Variable_or_constant_or_nat))
; (fun __caml_parser_env ->
    Obj.repr(
# 1542 "parser.mly"
  ( Error_handler.errorNumber := 1 )
# 3542 "parser.ml"
               : 'err01))
; (fun __caml_parser_env ->
    Obj.repr(
# 1546 "parser.mly"
  ( Error_handler.errorNumber := 2 )
# 3548 "parser.ml"
               : 'err02))
; (fun __caml_parser_env ->
    Obj.repr(
# 1550 "parser.mly"
  ( Error_handler.errorNumber := 201 )
# 3554 "parser.ml"
               : 'err201))
; (fun __caml_parser_env ->
    Obj.repr(
# 1554 "parser.mly"
  ( Error_handler.errorNumber := 3 )
# 3560 "parser.ml"
               : 'err03))
; (fun __caml_parser_env ->
    Obj.repr(
# 1558 "parser.mly"
  ( Error_handler.errorNumber := 4 )
# 3566 "parser.ml"
               : 'err04))
; (fun __caml_parser_env ->
    Obj.repr(
# 1562 "parser.mly"
  ( Error_handler.errorNumber := 5 )
# 3572 "parser.ml"
               : 'err05))
; (fun __caml_parser_env ->
    Obj.repr(
# 1566 "parser.mly"
  ( Error_handler.errorNumber := 6 )
# 3578 "parser.ml"
               : 'err06))
; (fun __caml_parser_env ->
    Obj.repr(
# 1570 "parser.mly"
  ( Error_handler.errorNumber := 7 )
# 3584 "parser.ml"
               : 'err07))
; (fun __caml_parser_env ->
    Obj.repr(
# 1574 "parser.mly"
  ( Error_handler.errorNumber := 701 )
# 3590 "parser.ml"
               : 'err701))
; (fun __caml_parser_env ->
    Obj.repr(
# 1578 "parser.mly"
  ( Error_handler.errorNumber := 702 )
# 3596 "parser.ml"
               : 'err702))
; (fun __caml_parser_env ->
    Obj.repr(
# 1582 "parser.mly"
  ( Error_handler.errorNumber := 8 )
# 3602 "parser.ml"
               : 'err08))
; (fun __caml_parser_env ->
    Obj.repr(
# 1586 "parser.mly"
  ( Error_handler.errorNumber := 9 )
# 3608 "parser.ml"
               : 'err09))
; (fun __caml_parser_env ->
    Obj.repr(
# 1590 "parser.mly"
  ( Error_handler.errorNumber := 10 )
# 3614 "parser.ml"
               : 'err10))
; (fun __caml_parser_env ->
    Obj.repr(
# 1594 "parser.mly"
  ( Error_handler.errorNumber := 11 )
# 3620 "parser.ml"
               : 'err11))
; (fun __caml_parser_env ->
    Obj.repr(
# 1598 "parser.mly"
  ( Error_handler.errorNumber := 12 )
# 3626 "parser.ml"
               : 'err12))
; (fun __caml_parser_env ->
    Obj.repr(
# 1602 "parser.mly"
  ( Error_handler.errorNumber := 13 )
# 3632 "parser.ml"
               : 'err13))
; (fun __caml_parser_env ->
    Obj.repr(
# 1606 "parser.mly"
  ( Error_handler.errorNumber := 14 )
# 3638 "parser.ml"
               : 'err14))
; (fun __caml_parser_env ->
    Obj.repr(
# 1610 "parser.mly"
  ( Error_handler.errorNumber := 15 )
# 3644 "parser.ml"
               : 'err15))
; (fun __caml_parser_env ->
    Obj.repr(
# 1614 "parser.mly"
  ( Error_handler.errorNumber := 16 )
# 3650 "parser.ml"
               : 'err16))
; (fun __caml_parser_env ->
    Obj.repr(
# 1618 "parser.mly"
  ( Error_handler.errorNumber := 161 )
# 3656 "parser.ml"
               : 'err161))
; (fun __caml_parser_env ->
    Obj.repr(
# 1622 "parser.mly"
  ( Error_handler.errorNumber := 18 )
# 3662 "parser.ml"
               : 'err18))
; (fun __caml_parser_env ->
    Obj.repr(
# 1626 "parser.mly"
  ( Error_handler.errorNumber := 19 )
# 3668 "parser.ml"
               : 'err19))
; (fun __caml_parser_env ->
    Obj.repr(
# 1630 "parser.mly"
  ( Error_handler.errorNumber := 202 )
# 3674 "parser.ml"
               : 'err202))
; (fun __caml_parser_env ->
    Obj.repr(
# 1634 "parser.mly"
  ( Error_handler.errorNumber := 21 )
# 3680 "parser.ml"
               : 'err21))
; (fun __caml_parser_env ->
    Obj.repr(
# 1638 "parser.mly"
  ( Error_handler.errorNumber := 22 )
# 3686 "parser.ml"
               : 'err22))
; (fun __caml_parser_env ->
    Obj.repr(
# 1642 "parser.mly"
  ( Error_handler.errorNumber := 23 )
# 3692 "parser.ml"
               : 'err23))
; (fun __caml_parser_env ->
    Obj.repr(
# 1646 "parser.mly"
  ( Error_handler.errorNumber := 241 )
# 3698 "parser.ml"
               : 'err241))
; (fun __caml_parser_env ->
    Obj.repr(
# 1649 "parser.mly"
  ( Error_handler.errorNumber := 242 )
# 3704 "parser.ml"
               : 'err242))
; (fun __caml_parser_env ->
    Obj.repr(
# 1652 "parser.mly"
  ( Error_handler.errorNumber := 243 )
# 3710 "parser.ml"
               : 'err243))
; (fun __caml_parser_env ->
    Obj.repr(
# 1660 "parser.mly"
  ( Error_handler.errorNumber := 27 )
# 3716 "parser.ml"
               : 'err27))
; (fun __caml_parser_env ->
    Obj.repr(
# 1664 "parser.mly"
  ( Error_handler.errorNumber := 28 )
# 3722 "parser.ml"
               : 'err28))
; (fun __caml_parser_env ->
    Obj.repr(
# 1668 "parser.mly"
  ( Error_handler.errorNumber := 29 )
# 3728 "parser.ml"
               : 'err29))
; (fun __caml_parser_env ->
    Obj.repr(
# 1672 "parser.mly"
  ( Error_handler.errorNumber := 30 )
# 3734 "parser.ml"
               : 'err30))
; (fun __caml_parser_env ->
    Obj.repr(
# 1676 "parser.mly"
  ( Error_handler.errorNumber := 31 )
# 3740 "parser.ml"
               : 'err31))
; (fun __caml_parser_env ->
    Obj.repr(
# 1680 "parser.mly"
  ( Error_handler.errorNumber := 311 )
# 3746 "parser.ml"
               : 'err311))
; (fun __caml_parser_env ->
    Obj.repr(
# 1684 "parser.mly"
  ( Error_handler.errorNumber := 312 )
# 3752 "parser.ml"
               : 'err312))
; (fun __caml_parser_env ->
    Obj.repr(
# 1688 "parser.mly"
  ( Error_handler.errorNumber := 313 )
# 3758 "parser.ml"
               : 'err313))
; (fun __caml_parser_env ->
    Obj.repr(
# 1692 "parser.mly"
  ( Error_handler.errorNumber := 314 )
# 3764 "parser.ml"
               : 'err314))
; (fun __caml_parser_env ->
    Obj.repr(
# 1696 "parser.mly"
  ( Error_handler.errorNumber := 315 )
# 3770 "parser.ml"
               : 'err315))
; (fun __caml_parser_env ->
    Obj.repr(
# 1700 "parser.mly"
  ( Error_handler.errorNumber := 316 )
# 3776 "parser.ml"
               : 'err316))
; (fun __caml_parser_env ->
    Obj.repr(
# 1704 "parser.mly"
  ( Error_handler.errorNumber := 317 )
# 3782 "parser.ml"
               : 'err317))
; (fun __caml_parser_env ->
    Obj.repr(
# 1708 "parser.mly"
  ( Error_handler.errorNumber := 32 )
# 3788 "parser.ml"
               : 'err32))
; (fun __caml_parser_env ->
    Obj.repr(
# 1712 "parser.mly"
  ( Error_handler.errorNumber := 33 )
# 3794 "parser.ml"
               : 'err33))
; (fun __caml_parser_env ->
    Obj.repr(
# 1716 "parser.mly"
  ( Error_handler.errorNumber := 34 )
# 3800 "parser.ml"
               : 'err34))
; (fun __caml_parser_env ->
    Obj.repr(
# 1720 "parser.mly"
  ( Error_handler.errorNumber := 35 )
# 3806 "parser.ml"
               : 'err35))
; (fun __caml_parser_env ->
    Obj.repr(
# 1724 "parser.mly"
  ( Error_handler.errorNumber := 351 )
# 3812 "parser.ml"
               : 'err351))
; (fun __caml_parser_env ->
    Obj.repr(
# 1728 "parser.mly"
  ( Error_handler.errorNumber := 352 )
# 3818 "parser.ml"
               : 'err352))
; (fun __caml_parser_env ->
    Obj.repr(
# 1732 "parser.mly"
  ( Error_handler.errorNumber := 36 )
# 3824 "parser.ml"
               : 'err36))
; (fun __caml_parser_env ->
    Obj.repr(
# 1736 "parser.mly"
  ( Error_handler.errorNumber := 37 )
# 3830 "parser.ml"
               : 'err37))
; (fun __caml_parser_env ->
    Obj.repr(
# 1740 "parser.mly"
  ( Error_handler.errorNumber := 38 )
# 3836 "parser.ml"
               : 'err38))
(* Entry specification *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let specification (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Types.specification_class)
